@@ -1,6 +1,6 @@
 /*! \file */
 /* ************************************************************************
-* Copyright (C) 2021-2023 Advanced Micro Devices, Inc. All rights Reserved.
+* Copyright (C) 2021-2024 Advanced Micro Devices, Inc. All rights Reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
@@ -25,6 +25,7 @@
 #include "rocsparse_arguments_config.hpp"
 #include "rocsparse_clients_matrices_dir.hpp"
 #include "rocsparse_enum.hpp"
+#include "rocsparse_importer_format_t.hpp"
 
 rocsparse_arguments_config::rocsparse_arguments_config()
 {
@@ -102,32 +103,33 @@ rocsparse_arguments_config::rocsparse_arguments_config()
         this->gtsv_interleaved_alg = static_cast<rocsparse_gtsv_interleaved_alg>(0);
         this->gpsv_interleaved_alg = static_cast<rocsparse_gpsv_interleaved_alg>(0);
 
-        this->matrix           = static_cast<rocsparse_matrix_init>(0);
-        this->matrix_init_kind = static_cast<rocsparse_matrix_init_kind>(0);
-        this->unit_check       = static_cast<rocsparse_int>(0);
-        this->timing           = static_cast<rocsparse_int>(1);
-        this->iters            = static_cast<rocsparse_int>(0);
-        this->denseld          = static_cast<int64_t>(0);
-        this->batch_count      = static_cast<rocsparse_int>(0);
-        this->batch_count_A    = static_cast<rocsparse_int>(0);
-        this->batch_count_B    = static_cast<rocsparse_int>(0);
-        this->batch_count_C    = static_cast<rocsparse_int>(0);
-        this->batch_stride     = static_cast<rocsparse_int>(0);
-        this->ld_multiplier_B  = static_cast<rocsparse_int>(2);
-        this->ld_multiplier_C  = static_cast<rocsparse_int>(2);
-        this->algo             = static_cast<uint32_t>(0);
-        this->numericboost     = static_cast<int>(0);
-        this->boosttol         = static_cast<double>(0);
-        this->boostval         = static_cast<double>(0);
-        this->boostvali        = static_cast<double>(0);
-        this->tolm             = static_cast<double>(0);
-        this->graph_test       = static_cast<bool>(0);
-        this->filename[0]      = '\0';
-        this->function[0]      = '\0';
-        this->name[0]          = '\0';
-        this->category[0]      = '\0';
-        this->hardware[0]      = '\0';
-        this->skip_hardware[0] = '\0';
+        this->matrix               = static_cast<rocsparse_matrix_init>(0);
+        this->matrix_init_kind     = static_cast<rocsparse_matrix_init_kind>(0);
+        this->unit_check           = static_cast<rocsparse_int>(0);
+        this->timing               = static_cast<rocsparse_int>(1);
+        this->iters                = static_cast<rocsparse_int>(0);
+        this->denseld              = static_cast<int64_t>(0);
+        this->batch_count          = static_cast<rocsparse_int>(0);
+        this->batch_count_A        = static_cast<rocsparse_int>(0);
+        this->batch_count_B        = static_cast<rocsparse_int>(0);
+        this->batch_count_C        = static_cast<rocsparse_int>(0);
+        this->batch_stride         = static_cast<rocsparse_int>(0);
+        this->ld_multiplier_B      = static_cast<rocsparse_int>(2);
+        this->ld_multiplier_C      = static_cast<rocsparse_int>(2);
+        this->algo                 = static_cast<uint32_t>(0);
+        this->numericboost         = static_cast<int>(0);
+        this->boosttol             = static_cast<double>(0);
+        this->boostval             = static_cast<double>(0);
+        this->boostvali            = static_cast<double>(0);
+        this->tolm                 = static_cast<double>(0);
+        this->graph_test           = static_cast<bool>(0);
+        this->skip_reproducibility = static_cast<bool>(0);
+        this->filename[0]          = '\0';
+        this->function[0]          = '\0';
+        this->name[0]              = '\0';
+        this->category[0]          = '\0';
+        this->hardware[0]          = '\0';
+        this->skip_hardware[0]     = '\0';
     }
 
     this->precision = 's';
@@ -317,7 +319,7 @@ void rocsparse_arguments_config::set_description(options_description& desc)
      "  Conversion: csr2coo, csr2csc, gebsr2gebsc, csr2ell, csr2hyb, csr2bsr, csr2gebsr\n"
      "              coo2csr, ell2csr, hyb2csr, dense2csr, dense2coo, prune_dense2csr, prune_dense2csr_by_percentage, dense2csc\n"
      "              csr2dense, csc2dense, coo2dense, bsr2csr, gebsr2csr, gebsr2gebsr, csr2csr_compress, prune_csr2csr, prune_csr2csr_by_percentage\n"
-     "              sparse_to_dense_coo, sparse_to_dense_csr, sparse_to_dense_csc, dense_to_sparse_coo, dense_to_sparse_csr, dense_to_sparse_csc, sparse_to_sparse\n"
+     "              sparse_to_dense_coo, sparse_to_dense_csr, sparse_to_dense_csc, dense_to_sparse_coo, dense_to_sparse_csr, dense_to_sparse_csc, sparse_to_sparse, extract\n"
      "  Sorting: cscsort, csrsort, coosort\n"
      "  Misc: identity, inverse_permutation, nnz\n"
      "  Util: check_matrix_csr, check_matrix_csc, check_matrix_coo, check_matrix_gebsr, check_matrix_gebsc, check_matrix_ell, check_matrix_hyb")
@@ -334,7 +336,7 @@ void rocsparse_arguments_config::set_description(options_description& desc)
      "Validate GPU results with CPU? 0 = No, 1 = Yes (default: No)")
 
     ("iters,i",
-     value<int>(&this->iters)->default_value(10),
+     value<rocsparse_int>(&this->iters)->default_value(10),
      "Iterations to run inside timing loop")
 
     ("device,d",
@@ -409,7 +411,7 @@ void rocsparse_arguments_config::set_description(options_description& desc)
 
     ("spmm_alg",
       value<rocsparse_int>(&this->b_spmm_alg)->default_value(rocsparse_spmm_alg_default),
-      "Indicates what algorithm to use when running SpMM. Possibly choices are default: 0, CSR: 1, COO segmented: 2, COO atomic: 3, CSR row split: 4, CSR merge: 5, COO segmented atomic: 6, BELL: 7 (default:0)")
+      "Indicates what algorithm to use when running SpMM. Possibly choices are default: 0, CSR: 1, COO segmented: 2, COO atomic: 3, CSR row split: 4, CSR merge: 5, COO segmented atomic: 6, BELL: 7, BSR: 8, CSR merge-path: 9, CSR non-zero split: 5 (default:0)")
 
     ("sddmm_alg",
       value<rocsparse_int>(&this->b_sddmm_alg)->default_value(rocsparse_sddmm_alg_default),
@@ -524,10 +526,12 @@ int rocsparse_arguments_config::parse(int&argc,char**&argv, options_description&
 
   if(this->b_spmm_alg != rocsparse_spmm_alg_default
        && this->b_spmm_alg != rocsparse_spmm_alg_csr
+       && this->b_spmm_alg != rocsparse_spmm_alg_bsr
        && this->b_spmm_alg != rocsparse_spmm_alg_coo_segmented
        && this->b_spmm_alg != rocsparse_spmm_alg_coo_atomic
        && this->b_spmm_alg != rocsparse_spmm_alg_csr_row_split
-       && this->b_spmm_alg != rocsparse_spmm_alg_csr_merge
+       && this->b_spmm_alg != rocsparse_spmm_alg_csr_nnz_split
+       && this->b_spmm_alg != rocsparse_spmm_alg_csr_merge_path
        && this->b_spmm_alg != rocsparse_spmm_alg_coo_segmented_atomic
        && this->b_spmm_alg != rocsparse_spmm_alg_bell)
   {
@@ -622,10 +626,53 @@ int rocsparse_arguments_config::parse(int&argc,char**&argv, options_description&
     rocsparse_clients_matrices_dir_set(this->b_matrices_dir.c_str());
   }
 
-  // rocALUTION parameter overrides filename parameter
   if(this->b_file != "")
   {
     strcpy(this->filename, this->b_file.c_str());
+
+    rocsparse_importer_format_t importer_format;
+    importer_format(this->filename);
+    switch(importer_format.value)
+      {
+      case rocsparse_importer_format_t::matrixmarket:
+	{
+	  this->matrix = rocsparse_matrix_file_mtx;
+	  break;
+	}
+      case rocsparse_importer_format_t::mlcsr:
+	{
+	  this->matrix = rocsparse_matrix_file_smtx;
+	  break;
+	}
+      case rocsparse_importer_format_t::mlbsr:
+	{
+	  this->matrix = rocsparse_matrix_file_bsmtx;
+	  break;
+	}
+      case rocsparse_importer_format_t::rocalution:
+	{
+	  this->matrix = rocsparse_matrix_file_rocalution;
+	  break;
+	}
+      case rocsparse_importer_format_t::rocsparseio:
+	{
+	  this->matrix = rocsparse_matrix_file_rocsparseio;
+	  break;
+	}
+      case rocsparse_importer_format_t::unknown:
+	{
+	  std::cerr << "No extension is detected in the filename '"<< b_file <<"' " << std::endl;
+	  std::cerr << "The list of detectable extensions is : " << std::endl;
+	  for (auto format : rocsparse_importer_format_t::all_formats)
+	    {
+	      if (rocsparse_importer_format_t::unknown != format)
+		{
+		  std::cerr << " - '" << rocsparse_importer_format_t::extension(format) << "'" << std::endl;
+		}
+	    }
+	  return -1;
+	}
+      }
   }
   else if(this->b_rocsparseio != "")
   {
@@ -637,14 +684,6 @@ int rocsparse_arguments_config::parse(int&argc,char**&argv, options_description&
     strcpy(this->filename, this->b_rocalution.c_str());
     this->matrix = rocsparse_matrix_file_rocalution;
   }
-  else if(this->dimx != 0 && this->dimy != 0 && this->dimz != 0)
-  {
-    this->matrix = rocsparse_matrix_laplace_3d;
-  }
-  else if(this->dimx != 0 && this->dimy != 0)
-  {
-    this->matrix = rocsparse_matrix_laplace_2d;
-  }
   else if(this->b_matrixmarket != "")
   {
     strcpy(this->filename, this->b_matrixmarket.c_str());
@@ -660,6 +699,14 @@ int rocsparse_arguments_config::parse(int&argc,char**&argv, options_description&
     strcpy(this->filename, this->b_mlbsr.c_str());
     this->matrix = rocsparse_matrix_file_bsmtx;
   }
+  else if(this->dimx != 0 && this->dimy != 0 && this->dimz != 0)
+  {
+    this->matrix = rocsparse_matrix_laplace_3d;
+  }
+  else if(this->dimx != 0 && this->dimy != 0)
+  {
+    this->matrix = rocsparse_matrix_laplace_2d;
+  }
   else if(this->ll == 0 && this->l != 0 && this->u != 0 && this->uu == 0)
   {
     this->matrix = rocsparse_matrix_tridiagonal;
@@ -777,353 +824,3 @@ int rocsparse_arguments_config::parse(int&argc,char**&argv, options_description&
   return 0;
 }
 
-int rocsparse_arguments_config::parse_no_default(int&argc,char**&argv, options_description&desc)
-{
-  variables_map vm;
-  store(parse_command_line(argc, argv, desc), vm);
-  notify(vm);
-
-  if(vm.count("help"))
-  {
-    std::cout << desc << std::endl;
-    return -2;
-  }
-
-  if(this->b_dir != rocsparse_direction_row && this->b_dir != rocsparse_direction_column)
-  {
-    std::cerr << "Invalid value for --direction" << std::endl;
-    return -1;
-  }
-
-  if(this->b_order != rocsparse_order_row && this->b_order != rocsparse_order_column)
-  {
-    std::cerr << "Invalid value for --order" << std::endl;
-    return -1;
-  }
-
-  if(this->b_orderB != rocsparse_order_row && this->b_orderB != rocsparse_order_column)
-  {
-    std::cerr << "Invalid value for --orderB" << std::endl;
-    return -1;
-  }
-
-  if(this->b_orderC != rocsparse_order_row && this->b_orderC != rocsparse_order_column)
-  {
-    std::cerr << "Invalid value for --orderC" << std::endl;
-    return -1;
-  }
-
-  { bool is_format_invalid = true;
-    switch(this->b_formatA)
-      {
-      case rocsparse_format_csr:
-      case rocsparse_format_coo:
-      case rocsparse_format_ell:
-      case rocsparse_format_csc:
-      case rocsparse_format_coo_aos:
-      case rocsparse_format_bell:
-      case rocsparse_format_bsr:
-	{
-	  is_format_invalid = false;
-	  break;
-	}
-      }
-
-    if(is_format_invalid)
-      {
-	std::cerr << "Invalid value for --format" << std::endl;
-	return -1;
-      } }
-
-  { bool is_format_invalid = true;
-    switch(this->b_formatB)
-      {
-      case rocsparse_format_csr:
-      case rocsparse_format_coo:
-      case rocsparse_format_ell:
-      case rocsparse_format_csc:
-      case rocsparse_format_coo_aos:
-      case rocsparse_format_bell:
-      case rocsparse_format_bsr:
-	{
-	  is_format_invalid = false;
-	  break;
-	}
-      }
-
-    if(is_format_invalid)
-      {
-	std::cerr << "Invalid value for --formatB" << std::endl;
-	return -1;
-      } }
-
-  if(this->b_spmv_alg != rocsparse_spmv_alg_default
-       && this->b_spmv_alg != rocsparse_spmv_alg_coo
-       && this->b_spmv_alg != rocsparse_spmv_alg_csr_adaptive
-       && this->b_spmv_alg != rocsparse_spmv_alg_csr_stream
-       && this->b_spmv_alg != rocsparse_spmv_alg_ell
-       && this->b_spmv_alg != rocsparse_spmv_alg_coo_atomic
-       && this->b_spmv_alg != rocsparse_spmv_alg_csr_lrb)
-  {
-      std::cerr << "Invalid value for --spmv_alg" << std::endl;
-      return -1;
-  }
-
-  if(this->b_spmm_alg != rocsparse_spmm_alg_default
-       && this->b_spmm_alg != rocsparse_spmm_alg_csr
-       && this->b_spmm_alg != rocsparse_spmm_alg_coo_segmented
-       && this->b_spmm_alg != rocsparse_spmm_alg_coo_atomic
-       && this->b_spmm_alg != rocsparse_spmm_alg_csr_row_split
-       && this->b_spmm_alg != rocsparse_spmm_alg_csr_merge
-       && this->b_spmm_alg != rocsparse_spmm_alg_coo_segmented_atomic
-       && this->b_spmm_alg != rocsparse_spmm_alg_bell)
-  {
-      std::cerr << "Invalid value for --spmm_alg" << std::endl;
-      return -1;
-  }
-
-  if(this->b_sddmm_alg != rocsparse_sddmm_alg_default
-       && this->b_sddmm_alg != rocsparse_sddmm_alg_dense)
-  {
-      std::cerr << "Invalid value for --sddmm_alg" << std::endl;
-      return -1;
-  }
-
-  if(this->b_gtsv_interleaved_alg != rocsparse_gtsv_interleaved_alg_default
-       && this->b_gtsv_interleaved_alg != rocsparse_gtsv_interleaved_alg_thomas
-       && this->b_gtsv_interleaved_alg != rocsparse_gtsv_interleaved_alg_lu
-       && this->b_gtsv_interleaved_alg != rocsparse_gtsv_interleaved_alg_qr)
-  {
-      std::cerr << "Invalid value for --gtsv_interleaved_alg" << std::endl;
-      return -1;
-  }
-
-  if(b_transA == 'N')
-  {
-    this->transA = rocsparse_operation_none;
-  }
-  else if(b_transA == 'T')
-  {
-    this->transA = rocsparse_operation_transpose;
-  }
-  else if(b_transA == 'C')
-  {
-    this->transA = rocsparse_operation_conjugate_transpose;
-  }
-
-  if(b_transB == 'N')
-  {
-    this->transB = rocsparse_operation_none;
-  }
-  else if(b_transB == 'T')
-  {
-    this->transB = rocsparse_operation_transpose;
-  }
-  else if(b_transB == 'C')
-  {
-    this->transB = rocsparse_operation_conjugate_transpose;
-  }
-
-  sprintf(this->function,"%s",this->function_name.c_str());
-  this->baseA = (b_baseA == 0) ? rocsparse_index_base_zero : rocsparse_index_base_one;
-  this->baseB = (b_baseB == 0) ? rocsparse_index_base_zero : rocsparse_index_base_one;
-  this->baseC = (b_baseC == 0) ? rocsparse_index_base_zero : rocsparse_index_base_one;
-  this->baseD = (b_baseD == 0) ? rocsparse_index_base_zero : rocsparse_index_base_one;
-
-  this->action = (b_action == 0) ? rocsparse_action_numeric : rocsparse_action_symbolic;
-  this->part   = (b_part == 0)   ? rocsparse_hyb_partition_auto
-    : (b_part == 1) ? rocsparse_hyb_partition_user
-    : rocsparse_hyb_partition_max;
-  this->diag   = (b_diag == 'N') ? rocsparse_diag_type_non_unit : rocsparse_diag_type_unit;
-  this->uplo   = (b_uplo == 'L') ? rocsparse_fill_mode_lower : rocsparse_fill_mode_upper;
-  this->storage= (b_storage == 0) ? rocsparse_storage_mode_sorted : rocsparse_storage_mode_unsorted;
-  this->apol   = (b_apol == 'R') ? rocsparse_analysis_policy_reuse : rocsparse_analysis_policy_force;
-  this->spol   = rocsparse_solve_policy_auto;
-  this->direction
-    = (b_dir == rocsparse_direction_row) ? rocsparse_direction_row : rocsparse_direction_column;
-  this->order  = (b_order == rocsparse_order_row) ? rocsparse_order_row : rocsparse_order_column;
-  this->orderB  = (b_orderB == rocsparse_order_row) ? rocsparse_order_row : rocsparse_order_column;
-  this->orderC  = (b_orderC == rocsparse_order_row) ? rocsparse_order_row : rocsparse_order_column;
-  this->formatA = (rocsparse_format)b_formatA;
-  this->formatB = (rocsparse_format)b_formatB;
-  this->spmv_alg = (rocsparse_spmv_alg)this->b_spmv_alg;
-  this->spmm_alg = (rocsparse_spmm_alg)this->b_spmm_alg;
-  this->sddmm_alg = (rocsparse_sddmm_alg)this->b_sddmm_alg;
-  this->gtsv_interleaved_alg = (rocsparse_gtsv_interleaved_alg)this->b_gtsv_interleaved_alg;
-
-  if(this->b_matrices_dir != "")
-  {
-    rocsparse_clients_matrices_dir_set(this->b_matrices_dir.c_str());
-  }
-
-  // rocALUTION parameter overrides filename parameter
-
-  if(b_file != "")
-  {
-    strcpy(this->filename, b_file.c_str());
-    const char * p = b_file.c_str();
-    const char * q = nullptr;
-    while(*p!='\0') { if (*p=='.') q = p; ++p;}
-    if (q==nullptr)
-      {
-	std::cerr << "extension is not detected in filename '"<< b_file <<"' " << std::endl;
-	return -1;
-      }
-    if (!strcmp(q,".mtx"))
-      {
-	this->matrix = rocsparse_matrix_file_mtx;
-      }
-    else if (!strcmp(q,".bin"))
-      {
-	this->matrix = rocsparse_matrix_file_rocsparseio;
-      }
-    else if (!strcmp(q,".csr"))
-      {
-	this->matrix = rocsparse_matrix_file_rocalution;
-      }
-  }
-  else if(b_rocsparseio != "")
-  {
-    strcpy(this->filename, b_rocsparseio.c_str());
-    this->matrix = rocsparse_matrix_file_rocsparseio;
-  }
-  else if(b_rocalution != "")
-  {
-    strcpy(this->filename, b_rocalution.c_str());
-    this->matrix = rocsparse_matrix_file_rocalution;
-  }
-  else if(this->dimx != 0 && this->dimy != 0 && this->dimz != 0)
-  {
-    this->matrix = rocsparse_matrix_laplace_3d;
-  }
-  else if(this->dimx != 0 && this->dimy != 0)
-  {
-    this->matrix = rocsparse_matrix_laplace_2d;
-  }
-  else if(b_matrixmarket != "")
-  {
-    strcpy(this->filename, b_matrixmarket.c_str());
-    this->matrix = rocsparse_matrix_file_mtx;
-  }
-  else if(b_mlcsr != "")
-  {
-    strcpy(this->filename, b_mlcsr.c_str());
-    this->matrix = rocsparse_matrix_file_smtx;
-  }
-  else if(b_mlbsr != "")
-  {
-    strcpy(this->filename, b_mlbsr.c_str());
-    this->matrix = rocsparse_matrix_file_bsmtx;
-  }
-  else
-  {
-    this->matrix = rocsparse_matrix_random;
-  }
-
-  this->matrix_init_kind = rocsparse_matrix_init_kind_default;
-  /* ============================================================================================
-   */
-  if(this->M < 0 || this->N < 0)
-  {
-    std::cerr << "Invalid dimension" << std::endl;
-    return -1;
-  }
-
-  if(this->block_dim < 1)
-  {
-    std::cerr << "Invalid value for --blockdim" << std::endl;
-    return -1;
-  }
-
-  if(this->row_block_dimA < 1)
-  {
-    std::cerr << "Invalid value for --row-blockdimA" << std::endl;
-    return -1;
-  }
-
-  if(this->col_block_dimA < 1)
-  {
-    std::cerr << "Invalid value for --col-blockdimA" << std::endl;
-    return -1;
-  }
-
-  if(this->row_block_dimB < 1)
-  {
-    std::cerr << "Invalid value for --row-blockdimB" << std::endl;
-    return -1;
-  }
-
-  if(this->col_block_dimB < 1)
-  {
-    std::cerr << "Invalid value for --col-blockdimB" << std::endl;
-    return -1;
-  }
-
-
-
-  switch(this->indextype)
-    {
-    case 's':
-      {
-	this->index_type_I   = rocsparse_indextype_i32;
-	this->index_type_J   = rocsparse_indextype_i32;
-	break;
-      }
-    case 'd':
-      {
-	this->index_type_I   = rocsparse_indextype_i64;
-	this->index_type_J   = rocsparse_indextype_i64;
-	break;
-      }
-
-    case 'm':
-      {
-	this->index_type_I   = rocsparse_indextype_i64;
-	this->index_type_J   = rocsparse_indextype_i32;
-	break;
-      }
-    default:
-      {
-	std::cerr << "Invalid value for --indextype" << std::endl;
-	return -1;
-      }
-    }
-
-  switch(this->precision)
-    {
-    case 's':
-      {
-	this->compute_type = rocsparse_datatype_f32_r;
-  break;
-      }
-    case 'd':
-      {
-	this->compute_type = rocsparse_datatype_f64_r;
-	break;
-      }
-
-    case 'c':
-      {
-	this->compute_type = rocsparse_datatype_f32_c;
-	break;
-      }
-    case 'z':
-      {
-	this->compute_type = rocsparse_datatype_f64_c;
-	break;
-      }
-    default:
-      {
-	std::cerr << "Invalid value for --precision" << std::endl;
-	return -1;
-      }
-    }
-
-  this->A_row_indextype = this->index_type_I;
-  this->A_col_indextype = this->index_type_J;
-
-  return 0;
-}
-
-
-
