@@ -1,5 +1,5 @@
 /* ************************************************************************
-* Copyright (C) 2022-2023 Advanced Micro Devices, Inc. All rights Reserved.
+* Copyright (C) 2022-2024 Advanced Micro Devices, Inc. All rights Reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
@@ -73,12 +73,12 @@ void testing_spmm_batched_coo_bad_arg(const Arguments& arg)
     handle, trans_A, trans_B, &alpha, mat_A, mat_B, &beta, mat_C, ttype, alg, stage, buffer_size, \
         temp_buffer
 
-    int     batch_count_A;
-    int     batch_count_B;
-    int     batch_count_C;
-    int64_t batch_stride_A;
-    int64_t batch_stride_B;
-    int64_t batch_stride_C;
+    rocsparse_int batch_count_A;
+    rocsparse_int batch_count_B;
+    rocsparse_int batch_count_C;
+    int64_t       batch_stride_A;
+    int64_t       batch_stride_B;
+    int64_t       batch_stride_C;
 
     // C_i = A * B_i
     batch_count_A  = 1;
@@ -169,7 +169,7 @@ void testing_spmm_batched_coo(const Arguments& arg)
     }
 
     // Allocate host memory for matrix
-    rocsparse_matrix_factory<T, I> matrix_factory(arg);
+    rocsparse_matrix_factory<T, I, I> matrix_factory(arg);
 
     // Allocate host memory for matrix
     host_vector<I> hcoo_row_ind_temp;
