@@ -1,5 +1,5 @@
 /* ************************************************************************
-* Copyright (C) 2022-2023 Advanced Micro Devices, Inc. All rights Reserved.
+* Copyright (C) 2022-2024 Advanced Micro Devices, Inc. All rights Reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
@@ -61,17 +61,9 @@ void testing_spmm_batched_csc_bad_arg(const Arguments& arg)
     T beta  = static_cast<T>(0.0);
 
     // SpMM structures
-    rocsparse_local_spmat local_mat_A(m,
-                                      k,
-                                      nnz,
-                                      csc_col_ptr,
-                                      csc_row_ind,
-                                      csc_val,
-                                      itype,
-                                      jtype,
-                                      base,
-                                      ttype,
-                                      rocsparse_format_csc);
+    static const bool     use_csc_format = true;
+    rocsparse_local_spmat local_mat_A(
+        m, k, nnz, csc_col_ptr, csc_row_ind, csc_val, itype, jtype, base, ttype, use_csc_format);
     rocsparse_local_dnmat local_mat_B(k, n, k, B, ttype, order_B);
     rocsparse_local_dnmat local_mat_C(m, n, m, C, ttype, order_C);
 
@@ -83,13 +75,13 @@ void testing_spmm_batched_csc_bad_arg(const Arguments& arg)
     handle, trans_A, trans_B, &alpha, mat_A, mat_B, &beta, mat_C, ttype, alg, stage, buffer_size, \
         temp_buffer
 
-    int     batch_count_A;
-    int     batch_count_B;
-    int     batch_count_C;
-    int64_t offsets_batch_stride_A;
-    int64_t rows_values_batch_stride_A;
-    int64_t batch_stride_B;
-    int64_t batch_stride_C;
+    rocsparse_int batch_count_A;
+    rocsparse_int batch_count_B;
+    rocsparse_int batch_count_C;
+    int64_t       offsets_batch_stride_A;
+    int64_t       rows_values_batch_stride_A;
+    int64_t       batch_stride_B;
+    int64_t       batch_stride_C;
 
     // C_i = A * B_i
     batch_count_A              = 1;
@@ -281,6 +273,7 @@ void testing_spmm_batched_csc(const Arguments& arg)
     CHECK_HIP_ERROR(hipMemcpy(dbeta, &hbeta, sizeof(T), hipMemcpyHostToDevice));
 
     // Create descriptors
+    static const bool     use_csc_format = true;
     rocsparse_local_spmat A(A_m,
                             A_n,
                             nnz_A,
@@ -291,7 +284,7 @@ void testing_spmm_batched_csc(const Arguments& arg)
                             jtype,
                             base,
                             ttype,
-                            rocsparse_format_csc);
+                            use_csc_format);
 
     ldb = std::max(int64_t(1), ldb);
     ldc = std::max(int64_t(1), ldc);
