@@ -1,5 +1,5 @@
 /* ************************************************************************
-* Copyright (C) 2021-2023 Advanced Micro Devices, Inc. All rights Reserved.
+* Copyright (C) 2021-2024 Advanced Micro Devices, Inc. All rights Reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
@@ -129,7 +129,7 @@ void testing_spmm_coo(const Arguments& arg)
     host_vector<T> hcoo_val;
 
     // Allocate host memory for matrix
-    rocsparse_matrix_factory<T, I> matrix_factory(arg);
+    rocsparse_matrix_factory<T, I, I> matrix_factory(arg);
 
     int64_t nnz_A;
     matrix_factory.init_coo(hcoo_row_ind,
@@ -263,6 +263,10 @@ void testing_spmm_coo(const Arguments& arg)
                                                       rocsparse_spmm_stage_compute,
                                                       &buffer_size,
                                                       dbuffer));
+        if(ROCSPARSE_REPRODUCIBILITY)
+        {
+            rocsparse_reproducibility::save("dC_1", dC_1);
+        }
 
         // Pointer mode device
         CHECK_ROCSPARSE_ERROR(rocsparse_set_pointer_mode(handle, rocsparse_pointer_mode_device));
@@ -280,6 +284,11 @@ void testing_spmm_coo(const Arguments& arg)
                                                       &buffer_size,
                                                       dbuffer));
 
+        if(ROCSPARSE_REPRODUCIBILITY)
+        {
+            rocsparse_reproducibility::save("dC_2", dC_2);
+        }
+
         // Copy output to host
         CHECK_HIP_ERROR(hipMemcpy(hC_1, dC_1, sizeof(T) * nnz_C, hipMemcpyDeviceToHost));
         CHECK_HIP_ERROR(hipMemcpy(hC_2, dC_2, sizeof(T) * nnz_C, hipMemcpyDeviceToHost));
