@@ -1,5 +1,5 @@
 /* ************************************************************************
-* Copyright (C) 2022-2023 Advanced Micro Devices, Inc. All rights Reserved.
+* Copyright (C) 2022-2024 Advanced Micro Devices, Inc. All rights Reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
@@ -58,6 +58,7 @@ void testing_spmm_csc_bad_arg(const Arguments& arg)
     rocsparse_datatype  compute_type = get_datatype<T>();
 
     // SpMM structures
+    static const bool     csc_format_required = true;
     rocsparse_local_spmat local_mat_A(m,
                                       k,
                                       nnz,
@@ -68,7 +69,7 @@ void testing_spmm_csc_bad_arg(const Arguments& arg)
                                       jtype,
                                       base,
                                       compute_type,
-                                      rocsparse_format_csc);
+                                      csc_format_required);
     rocsparse_local_dnmat local_mat_B(k, n, k, B, compute_type, order_B);
     rocsparse_local_dnmat local_mat_C(m, n, m, C, compute_type, order_C);
 
@@ -211,6 +212,7 @@ void testing_spmm_csc(const Arguments& arg)
     CHECK_HIP_ERROR(hipMemcpy(dbeta, &hbeta, sizeof(T), hipMemcpyHostToDevice));
 
     // Create descriptors
+    static const bool     csc_format_required = true;
     rocsparse_local_spmat A(A_m,
                             A_n,
                             nnz_A,
@@ -221,7 +223,7 @@ void testing_spmm_csc(const Arguments& arg)
                             jtype,
                             base,
                             ttype,
-                            rocsparse_format_csc);
+                            csc_format_required);
 
     ldb = std::max(int64_t(1), ldb);
     ldc = std::max(int64_t(1), ldc);
@@ -283,6 +285,10 @@ void testing_spmm_csc(const Arguments& arg)
                                                       rocsparse_spmm_stage_compute,
                                                       &buffer_size,
                                                       dbuffer));
+        if(ROCSPARSE_REPRODUCIBILITY)
+        {
+            rocsparse_reproducibility::save("dC_1", dC_1);
+        }
 
         // Pointer mode device
         CHECK_ROCSPARSE_ERROR(rocsparse_set_pointer_mode(handle, rocsparse_pointer_mode_device));
@@ -300,6 +306,11 @@ void testing_spmm_csc(const Arguments& arg)
                                                       &buffer_size,
                                                       dbuffer));
 
+        if(ROCSPARSE_REPRODUCIBILITY)
+        {
+            rocsparse_reproducibility::save("dC_2", dC_2);
+        }
+
         // Copy output to host
         CHECK_HIP_ERROR(hipMemcpy(hC_1, dC_1, sizeof(T) * nnz_C, hipMemcpyDeviceToHost));
         CHECK_HIP_ERROR(hipMemcpy(hC_2, dC_2, sizeof(T) * nnz_C, hipMemcpyDeviceToHost));
