@@ -20,14 +20,18 @@ function display_help()
   echo "    [-g|--debug] -DCMAKE_BUILD_TYPE=Debug (default is =Release)"
   echo "    [-k|--relwithdebinfo] -DCMAKE_BUILD_TYPE=RelWithDebInfo"
   echo "    [--hip-clang] build library for amdgpu backend using hip-clang"
-  echo "    [--static] build static library"
+  echo "    [-s|--static] build static library"
   echo "    [--memstat] build with memory statistics enabled."
+  echo "    [--rocsparse_ILP64] build with rocsparse_int equal to int64_t."
   echo "    [--address-sanitizer] build with address sanitizer"
   echo "    [--codecoverage] build with code coverage profiling enabled"
+  echo "    [--rocprim-path] Specify path to an existing rocPRIM install directory (e.g. /src/rocPRIM/build/release/rocprim)"
+  echo "    [--rocblas-path] Specify path to an existing rocBLAS install directory (e.g. /src/rocBLAS/build/release/rocblas-install)"
   echo "    [--matrices-dir] existing client matrices directory"
   echo "    [--matrices-dir-install] install client matrices directory"
   echo "    [--rm-legacy-include-dir] Remove legacy include dir Packaging added for file/folder reorg backward compatibility."
   echo "    [--without-rocblas] Disable building rocSPARSE with rocBLAS."
+  echo "    [--cmake-arg] Forward the given argument to CMake when configuring the build."
 }
 
 # This function is helpful for dockerfiles that do not have sudo installed, but the default user is root
@@ -229,6 +233,11 @@ install_packages( )
   esac
 }
 
+# given a relative path, returns the absolute path
+make_absolute_path( ) {
+  (cd "$1" && pwd -P)
+}
+
 # #################################################
 # Pre-requisites check
 # #################################################
@@ -272,11 +281,14 @@ rocm_path=/opt/rocm
 build_relocatable=false
 build_address_sanitizer=false
 build_memstat=false
+build_rocsparse_ILP64=false
 build_with_rocblas=true
 matrices_dir=
 matrices_dir_install=
 gpu_architecture=all
 build_freorg_bkwdcomp=false
+declare -a cmake_common_options
+declare -a cmake_client_options
 
 # #################################################
 # Parameter parsing
@@ -285,7 +297,7 @@ build_freorg_bkwdcomp=false
 # check if we have a modern version of getopt that can handle whitespace and long parameters
 getopt -T
 if [[ $? -eq 4 ]]; then
-  GETOPT_PARSE=$(getopt --name "${0}" --longoptions help,install,clients,dependencies,debug,hip-clang,static,relocatable,codecoverage,relwithdebinfo,memstat,without-rocblas,address-sanitizer,matrices-dir:,matrices-dir-install:,architecture:,rm-legacy-include-dir --options hicdgrka: -- "$@")
+ GETOPT_PARSE=$(getopt --name "${0}" --longoptions help,install,clients,dependencies,debug,hip-clang,static,relocatable,codecoverage,relwithdebinfo,memstat,rocsparse_ILP64,rocprim-path:,rocblas-path:,without-rocblas,address-sanitizer,matrices-dir:,matrices-dir-install:,architecture:,rm-legacy-include-dir,cmake-arg: --options hicdgrska: -- "$@")
 
 else
   echo "Need a new version of getopt"
@@ -323,7 +335,7 @@ while true; do
         --hip-clang)
             build_hip_clang=true
             shift ;;
-        --static)
+        -s|--static)
             build_static=true
             shift ;;
         --address-sanitizer)
@@ -332,6 +344,15 @@ while true; do
         --memstat)
             build_memstat=true
             shift ;;
+        --rocsparse_ILP64)
+            build_rocsparse_ILP64=true
+            shift ;;
+        --rocprim-path)
+            rocprim_path=${2}
+            shift 2 ;;
+        --rocblas-path)
+            rocblas_path=${2}
+            shift 2 ;;
         --without-rocblas)
             build_with_rocblas=false
             shift ;;
@@ -348,6 +369,9 @@ while true; do
         -a|--architecture)
             gpu_architecture=${2}
             shift 2 ;;
+        --cmake-arg)
+            cmake_common_options+=("${2}")
+            shift 2 ;;
         --matrices-dir)
             matrices_dir=${2}
             if [[ "${matrices_dir}" == "" ]];then
@@ -372,11 +396,24 @@ while true; do
     esac
 done
 
+
+if [[ -n "$CXX" ]]; then
+    cxx_compiler="${CXX}"
+else
+    cxx_compiler="${rocm_path}/bin/amdclang++"
+fi
+
+if [[ -n "$CC" ]]; then
+    cc_compiler="${CC}"
+else
+    cc_compiler="${rocm_path}/bin/amdclang"
+fi
+
 #
 # If matrices_dir_install has been set up then install matrices dir and exit.
 #
 if ! [[ "${matrices_dir_install}" == "" ]];then
-    cmake -DCMAKE_CXX_COMPILER="${rocm_path}/bin/hipcc" -DCMAKE_C_COMPILER="${rocm_path}/bin/hipcc"  -DPROJECT_BINARY_DIR=${matrices_dir_install} -DCMAKE_MATRICES_DIR=${matrices_dir_install} -DROCM_PATH=${rocm_path} -DCMAKE_INSTALL_LIBDIR=lib -P ./cmake/ClientMatrices.cmake
+    cmake -DCMAKE_CXX_COMPILER=${cxx_compiler}  -DCMAKE_C_COMPILER=${cc_compiler} -DPROJECT_BINARY_DIR=${matrices_dir_install} -DCMAKE_MATRICES_DIR=${matrices_dir_install} -DROCM_PATH=${rocm_path} -DCMAKE_INSTALL_LIBDIR=lib -P ./cmake/ClientMatrices.cmake
     exit 0
 fi
 
@@ -393,7 +430,7 @@ if ! [[ "${matrices_dir}" == "" ]];then
     # Let's 'reinstall' to the specified location to check if all good
     # Will be fast if everything already exists as expected.
     # This is to prevent any empty directory.
-    cmake -DCMAKE_CXX_COMPILER="${rocm_path}/bin/hipcc" -DCMAKE_C_COMPILER="${rocm_path}/bin/hipcc" -DPROJECT_BINARY_DIR=${matrices_dir} -DCMAKE_MATRICES_DIR=${matrices_dir} -DROCM_PATH=${rocm_path} -DCMAKE_INSTALL_LIBDIR=lib -P ./cmake/ClientMatrices.cmake
+    cmake -DCMAKE_CXX_COMPILER=${cxx_compiler}  -DCMAKE_C_COMPILER=${cc_compiler}  -DPROJECT_BINARY_DIR=${matrices_dir} -DCMAKE_MATRICES_DIR=${matrices_dir} -DROCM_PATH=${rocm_path} -DCMAKE_INSTALL_LIBDIR=lib -P ./cmake/ClientMatrices.cmake
 fi
 
 build_dir=./build
@@ -411,6 +448,14 @@ else
   rm -rf ${build_dir}/debug
 fi
 
+# resolve relative paths
+if [[ -n "${rocprim_path+x}" ]]; then
+  rocprim_path="$(make_absolute_path "${rocprim_path}")"
+fi
+if [[ -n "${rocblas_path+x}" ]]; then
+  rocblas_path="$(make_absolute_path "${rocblas_path}")"
+fi
+
 # Default cmake executable is called cmake
 cmake_executable=cmake
 
@@ -447,10 +492,14 @@ if [[ "${build_relocatable}" == true ]]; then
     if ! [ -z ${ROCM_PATH+x} ]; then
         rocm_path=${ROCM_PATH}
     fi
-
-    rocm_rpath=" -Wl,--enable-new-dtags -Wl,--rpath,/opt/rocm/lib:/opt/rocm/lib64"
+    if [[ "${cxx_compiler}" =~ .*amdclang\+\+ ]]; then
+        rpath_sep="="
+    else
+        rpath_sep=","
+    fi
+    rocm_rpath=" -Wl,--enable-new-dtags -Wl,--rpath${rpath_sep}/opt/rocm/lib:/opt/rocm/lib64"
     if ! [ -z ${ROCM_RPATH+x} ]; then
-        rocm_rpath=" -Wl,--enable-new-dtags -Wl,--rpath,${ROCM_RPATH}"
+        rocm_rpath=" -Wl,--enable-new-dtags -Wl,--rpath${rpath_sep}${ROCM_RPATH}"
     fi
 fi
 
@@ -466,44 +515,48 @@ pushd .
   # #################################################
   # configure & build
   # #################################################
-  cmake_common_options="-DAMDGPU_TARGETS=${gpu_architecture}"
-  cmake_client_options=""
+  cmake_common_options+=("--toolchain=toolchain-linux.cmake -DAMDGPU_TARGETS=${gpu_architecture}")
 
   # build type
   if [[ "${build_release}" == true ]]; then
     mkdir -p ${build_dir}/release/clients && cd ${build_dir}/release
-    cmake_common_options="${cmake_common_options} -DCMAKE_BUILD_TYPE=Release"
+    cmake_common_options+=("-DCMAKE_BUILD_TYPE=Release")
   elif [[ "${build_release_debug}" == true ]]; then
     mkdir -p ${build_dir}/release-debug/clients && cd ${build_dir}/release-debug
-    cmake_common_options="${cmake_common_options}  -DCMAKE_BUILD_TYPE=RelWithDebInfo"
+    cmake_common_options+=("-DCMAKE_BUILD_TYPE=RelWithDebInfo")
   else
     mkdir -p ${build_dir}/debug/clients && cd ${build_dir}/debug
-    cmake_common_options="${cmake_common_options} -DCMAKE_BUILD_TYPE=Debug"
+    cmake_common_options+=("-DCMAKE_BUILD_TYPE=Debug")
   fi
 
   # address sanitizer
   if [[ "${build_address_sanitizer}" == true ]]; then
-    cmake_common_options="${cmake_common_options} -DBUILD_ADDRESS_SANITIZER=ON"
+    cmake_common_options+=("-DBUILD_ADDRESS_SANITIZER=ON")
   fi
 
 
   # memstat
   if [[ "${build_memstat}" == true ]]; then
-    cmake_common_options="${cmake_common_options} -DBUILD_MEMSTAT=ON"
+    cmake_common_options+=("-DBUILD_MEMSTAT=ON")
+  fi
+
+  # rocsparse_ILP64
+  if [[ "${build_rocsparse_ILP64}" == true ]]; then
+    cmake_common_options+=("-DBUILD_ROCSPARSE_ILP64=ON")
   fi
 
   # without-rocblas
   if [[ "${build_with_rocblas}" == true ]]; then
-    cmake_common_options="${cmake_common_options} -DBUILD_WITH_ROCBLAS=ON"
+    cmake_common_options+=("-DBUILD_WITH_ROCBLAS=ON")
   else
-    cmake_common_options="${cmake_common_options} -DBUILD_WITH_ROCBLAS=OFF"
+    cmake_common_options+=("-DBUILD_WITH_ROCBLAS=OFF")
   fi
 
   # freorg backward compatible support enable
   if [[ "${build_freorg_bkwdcomp}" == true ]]; then
-    cmake_common_options="${cmake_common_options} -DBUILD_FILE_REORG_BACKWARD_COMPATIBILITY=ON"
+    cmake_common_options+=("-DBUILD_FILE_REORG_BACKWARD_COMPATIBILITY=ON")
   else
-    cmake_common_options="${cmake_common_options} -DBUILD_FILE_REORG_BACKWARD_COMPATIBILITY=OFF"
+    cmake_common_options+=("-DBUILD_FILE_REORG_BACKWARD_COMPATIBILITY=OFF")
   fi
 
   # code coverage
@@ -512,37 +565,38 @@ pushd .
           echo "Code coverage is disabled in Release mode, to enable code coverage select either Debug mode (-g | --debug) or RelWithDebInfo mode (-k | --relwithdebinfo); aborting";
           exit 1
       fi
-      cmake_common_options="${cmake_common_options} -DBUILD_CODE_COVERAGE=ON"
+      cmake_common_options+=("-DBUILD_CODE_COVERAGE=ON")
   fi
 
   # library type
   if [[ "${build_static}" == true ]]; then
-    cmake_common_options="{cmake_common_options} -DBUILD_SHARED_LIBS=OFF"
+    cmake_common_options+=("-DBUILD_SHARED_LIBS=OFF")
   fi
 
   # clients
   if [[ "${build_clients}" == true ]]; then
-      cmake_client_options="${cmake_client_options} -DBUILD_CLIENTS_SAMPLES=ON -DBUILD_CLIENTS_TESTS=ON -DBUILD_CLIENTS_BENCHMARKS=ON"
+      cmake_client_options+=("-DBUILD_CLIENTS_SAMPLES=ON" "-DBUILD_CLIENTS_TESTS=ON" "-DBUILD_CLIENTS_BENCHMARKS=ON")
       #
       # Add matrices_dir if exists.
       #
       if ! [[ "${matrices_dir}" == "" ]];then
-          cmake_client_options="${cmake_client_options} -DCMAKE_MATRICES_DIR=${matrices_dir}"
+          cmake_client_options+=("-DCMAKE_MATRICES_DIR=${matrices_dir}")
       fi
   fi
 
-  compiler="hcc"
-  if [[ "${build_hip_clang}" == true ]]; then
-    compiler="${rocm_path}/bin/hipcc"
+  # custom rocprim
+  if [[ ${rocprim_path+foo} ]]; then
+    cmake_common_options+=("-Drocprim_DIR=${rocprim_path}/rocprim")
   fi
 
-  if [[ "${build_clients}" == false ]]; then
-    cmake_client_options=""
+  # custom rocblas
+  if [[ ${rocblas_path+foo} ]]; then
+    cmake_common_options+=("-Drocblas_DIR=${rocblas_path}/lib/cmake/rocblas")
   fi
 
   # Build library with AMD toolchain because of existence of device kernels
   if [[ "${build_relocatable}" == true ]]; then
-    FC=gfortran CXX=${compiler} CC=${compiler} ${cmake_executable} ${cmake_common_options} ${cmake_client_options} -DCPACK_SET_DESTDIR=OFF \
+    FC=gfortran ${cmake_executable} ${cmake_common_options[@]} ${cmake_client_options[@]} -DCPACK_SET_DESTDIR=OFF \
       -DCMAKE_INSTALL_PREFIX=${install_prefix} \
       -DCPACK_PACKAGING_INSTALL_PREFIX=${rocm_path} \
       -DCMAKE_SHARED_LINKER_FLAGS="${rocm_rpath}" \
@@ -551,7 +605,7 @@ pushd .
       -DROCM_DISABLE_LDCONFIG=ON \
       -DROCM_PATH="${rocm_path}" ../..
   else
-    FC=gfortran CXX=${compiler} CC=${compiler} ${cmake_executable} ${cmake_common_options} ${cmake_client_options} -DCPACK_SET_DESTDIR=OFF -DCMAKE_INSTALL_PREFIX=${install_prefix} -DCPACK_PACKAGING_INSTALL_PREFIX=${rocm_path} -DROCM_PATH="${rocm_path}" ../..
+    FC=gfortran ${cmake_executable} ${cmake_common_options[@]} ${cmake_client_options[@]} -DCPACK_SET_DESTDIR=OFF -DCMAKE_INSTALL_PREFIX=${install_prefix} -DCPACK_PACKAGING_INSTALL_PREFIX=${rocm_path} -DROCM_PATH="${rocm_path}" ../..
   fi
   check_exit_code "$?"
 
