@@ -1,6 +1,6 @@
 /*! \file */
 /* ************************************************************************
- * Copyright (C) 2018-2023 Advanced Micro Devices, Inc. All rights Reserved.
+ * Copyright (C) 2018-2024 Advanced Micro Devices, Inc. All rights Reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -23,7 +23,7 @@
  * ************************************************************************ */
 
 #include "internal/conversion/rocsparse_csr2hyb.h"
-#include "definitions.h"
+#include "control.h"
 #include "rocsparse_csr2hyb.hpp"
 #include "utility.h"
 
@@ -32,31 +32,89 @@
 
 #include <rocprim/rocprim.hpp>
 
+namespace rocsparse
+{
+    template <typename T>
+    static rocsparse_status clear_hyb_mat(rocsparse_handle        handle,
+                                          rocsparse_int           m,
+                                          rocsparse_int           n,
+                                          rocsparse_hyb_mat       hyb,
+                                          rocsparse_hyb_partition partition_type)
+    {
+        hyb->m         = m;
+        hyb->n         = n;
+        hyb->partition = partition_type;
+        hyb->ell_nnz   = 0;
+        hyb->ell_width = 0;
+        hyb->coo_nnz   = 0;
+
+        if(std::is_same<T, float>{})
+        {
+            hyb->data_type_T = rocsparse_datatype_f32_r;
+        }
+        else if(std::is_same<T, double>{})
+        {
+            hyb->data_type_T = rocsparse_datatype_f64_r;
+        }
+        else if(std::is_same<T, rocsparse_float_complex>{})
+        {
+            hyb->data_type_T = rocsparse_datatype_f32_c;
+        }
+        else if(std::is_same<T, rocsparse_double_complex>{})
+        {
+            hyb->data_type_T = rocsparse_datatype_f64_c;
+        }
+
+        if(hyb->ell_col_ind)
+        {
+            RETURN_IF_HIP_ERROR(rocsparse_hipFreeAsync(hyb->ell_col_ind, handle->stream));
+        }
+        if(hyb->ell_val)
+        {
+            RETURN_IF_HIP_ERROR(rocsparse_hipFreeAsync(hyb->ell_val, handle->stream));
+        }
+        if(hyb->coo_row_ind)
+        {
+            RETURN_IF_HIP_ERROR(rocsparse_hipFreeAsync(hyb->coo_row_ind, handle->stream));
+        }
+        if(hyb->coo_col_ind)
+        {
+            RETURN_IF_HIP_ERROR(rocsparse_hipFreeAsync(hyb->coo_col_ind, handle->stream));
+        }
+        if(hyb->coo_val)
+        {
+            RETURN_IF_HIP_ERROR(rocsparse_hipFreeAsync(hyb->coo_val, handle->stream));
+        }
+
+        return rocsparse_status_success;
+    }
+}
+
 template <typename T>
-rocsparse_status rocsparse_csr2hyb_template(rocsparse_handle          handle,
-                                            rocsparse_int             m,
-                                            rocsparse_int             n,
-                                            const rocsparse_mat_descr descr,
-                                            const T*                  csr_val,
-                                            const rocsparse_int*      csr_row_ptr,
-                                            const rocsparse_int*      csr_col_ind,
-                                            rocsparse_hyb_mat         hyb,
-                                            rocsparse_int             user_ell_width,
-                                            rocsparse_hyb_partition   partition_type)
+rocsparse_status rocsparse::csr2hyb_template(rocsparse_handle          handle,
+                                             rocsparse_int             m,
+                                             rocsparse_int             n,
+                                             const rocsparse_mat_descr descr,
+                                             const T*                  csr_val,
+                                             const rocsparse_int*      csr_row_ptr,
+                                             const rocsparse_int*      csr_col_ind,
+                                             rocsparse_hyb_mat         hyb,
+                                             rocsparse_int             user_ell_width,
+                                             rocsparse_hyb_partition   partition_type)
 {
     // Check for valid handle and matrix descriptor
     // Logging
-    log_trace(handle,
-              replaceX<T>("rocsparse_Xcsr2hyb"),
-              m,
-              n,
-              (const void*&)descr,
-              (const void*&)csr_val,
-              (const void*&)csr_row_ptr,
-              (const void*&)csr_col_ind,
-              (const void*&)hyb,
-              user_ell_width,
-              partition_type);
+    rocsparse::log_trace(handle,
+                         rocsparse::replaceX<T>("rocsparse_Xcsr2hyb"),
+                         m,
+                         n,
+                         (const void*&)descr,
+                         (const void*&)csr_val,
+                         (const void*&)csr_row_ptr,
+                         (const void*&)csr_col_ind,
+                         (const void*&)hyb,
+                         user_ell_width,
+                         partition_type);
 
     // Check matrix type
 
@@ -76,6 +134,9 @@ rocsparse_status rocsparse_csr2hyb_template(rocsparse_handle          handle,
     // Quick return if possible
     if(m == 0 || n == 0)
     {
+        // Clear HYB structure if already allocated
+        RETURN_IF_ROCSPARSE_ERROR(clear_hyb_mat<T>(handle, m, n, hyb, partition_type));
+
         return rocsparse_status_success;
     }
 
@@ -116,50 +177,7 @@ rocsparse_status rocsparse_csr2hyb_template(rocsparse_handle          handle,
     }
 
     // Clear HYB structure if already allocated
-    hyb->m         = m;
-    hyb->n         = n;
-    hyb->partition = partition_type;
-    hyb->ell_nnz   = 0;
-    hyb->ell_width = 0;
-    hyb->coo_nnz   = 0;
-
-    if(std::is_same<T, float>{})
-    {
-        hyb->data_type_T = rocsparse_datatype_f32_r;
-    }
-    else if(std::is_same<T, double>{})
-    {
-        hyb->data_type_T = rocsparse_datatype_f64_r;
-    }
-    else if(std::is_same<T, rocsparse_float_complex>{})
-    {
-        hyb->data_type_T = rocsparse_datatype_f32_c;
-    }
-    else if(std::is_same<T, rocsparse_double_complex>{})
-    {
-        hyb->data_type_T = rocsparse_datatype_f64_c;
-    }
-
-    if(hyb->ell_col_ind)
-    {
-        RETURN_IF_HIP_ERROR(rocsparse_hipFreeAsync(hyb->ell_col_ind, handle->stream));
-    }
-    if(hyb->ell_val)
-    {
-        RETURN_IF_HIP_ERROR(rocsparse_hipFreeAsync(hyb->ell_val, handle->stream));
-    }
-    if(hyb->coo_row_ind)
-    {
-        RETURN_IF_HIP_ERROR(rocsparse_hipFreeAsync(hyb->coo_row_ind, handle->stream));
-    }
-    if(hyb->coo_col_ind)
-    {
-        RETURN_IF_HIP_ERROR(rocsparse_hipFreeAsync(hyb->coo_col_ind, handle->stream));
-    }
-    if(hyb->coo_val)
-    {
-        RETURN_IF_HIP_ERROR(rocsparse_hipFreeAsync(hyb->coo_val, handle->stream));
-    }
+    RETURN_IF_ROCSPARSE_ERROR(clear_hyb_mat<T>(handle, m, n, hyb, partition_type));
 
     // Determine ELL width
 
@@ -185,7 +203,7 @@ rocsparse_status rocsparse_csr2hyb_template(rocsparse_handle          handle,
             (void**)&workspace, sizeof(rocsparse_int) * blocks, handle->stream));
 
         // HYB == ELL - no COO part - compute maximum nnz per row
-        RETURN_IF_HIPLAUNCHKERNELGGL_ERROR((ell_width_kernel_part1<CSR2ELL_DIM>),
+        RETURN_IF_HIPLAUNCHKERNELGGL_ERROR((rocsparse::ell_width_kernel_part1<CSR2ELL_DIM>),
                                            dim3(blocks),
                                            dim3(CSR2ELL_DIM),
                                            0,
@@ -194,7 +212,7 @@ rocsparse_status rocsparse_csr2hyb_template(rocsparse_handle          handle,
                                            csr_row_ptr,
                                            workspace);
 
-        RETURN_IF_HIPLAUNCHKERNELGGL_ERROR((ell_width_kernel_part2<CSR2ELL_DIM>),
+        RETURN_IF_HIPLAUNCHKERNELGGL_ERROR((rocsparse::ell_width_kernel_part2<CSR2ELL_DIM>),
                                            dim3(1),
                                            dim3(CSR2ELL_DIM),
                                            0,
@@ -249,7 +267,7 @@ rocsparse_status rocsparse_csr2hyb_template(rocsparse_handle          handle,
         }
         else
         {
-            RETURN_IF_HIPLAUNCHKERNELGGL_ERROR((hyb_coo_nnz<CSR2ELL_DIM>),
+            RETURN_IF_HIPLAUNCHKERNELGGL_ERROR((rocsparse::hyb_coo_nnz<CSR2ELL_DIM>),
                                                dim3((m - 1) / CSR2ELL_DIM + 1),
                                                dim3(CSR2ELL_DIM),
                                                0,
@@ -317,7 +335,7 @@ rocsparse_status rocsparse_csr2hyb_template(rocsparse_handle          handle,
     dim3 csr2ell_blocks((m - 1) / CSR2ELL_DIM + 1);
     dim3 csr2ell_threads(CSR2ELL_DIM);
 
-    RETURN_IF_HIPLAUNCHKERNELGGL_ERROR((csr2hyb_kernel<CSR2ELL_DIM>),
+    RETURN_IF_HIPLAUNCHKERNELGGL_ERROR((rocsparse::csr2hyb_kernel<CSR2ELL_DIM>),
                                        csr2ell_blocks,
                                        csr2ell_threads,
                                        0,
@@ -359,16 +377,16 @@ extern "C" rocsparse_status rocsparse_scsr2hyb(rocsparse_handle          handle,
                                                rocsparse_hyb_partition   partition_type)
 try
 {
-    RETURN_IF_ROCSPARSE_ERROR(rocsparse_csr2hyb_template(handle,
-                                                         m,
-                                                         n,
-                                                         descr,
-                                                         csr_val,
-                                                         csr_row_ptr,
-                                                         csr_col_ind,
-                                                         hyb,
-                                                         user_ell_width,
-                                                         partition_type));
+    RETURN_IF_ROCSPARSE_ERROR(rocsparse::csr2hyb_template(handle,
+                                                          m,
+                                                          n,
+                                                          descr,
+                                                          csr_val,
+                                                          csr_row_ptr,
+                                                          csr_col_ind,
+                                                          hyb,
+                                                          user_ell_width,
+                                                          partition_type));
     return rocsparse_status_success;
 }
 catch(...)
@@ -388,16 +406,16 @@ extern "C" rocsparse_status rocsparse_dcsr2hyb(rocsparse_handle          handle,
                                                rocsparse_hyb_partition   partition_type)
 try
 {
-    RETURN_IF_ROCSPARSE_ERROR(rocsparse_csr2hyb_template(handle,
-                                                         m,
-                                                         n,
-                                                         descr,
-                                                         csr_val,
-                                                         csr_row_ptr,
-                                                         csr_col_ind,
-                                                         hyb,
-                                                         user_ell_width,
-                                                         partition_type));
+    RETURN_IF_ROCSPARSE_ERROR(rocsparse::csr2hyb_template(handle,
+                                                          m,
+                                                          n,
+                                                          descr,
+                                                          csr_val,
+                                                          csr_row_ptr,
+                                                          csr_col_ind,
+                                                          hyb,
+                                                          user_ell_width,
+                                                          partition_type));
     return rocsparse_status_success;
 }
 catch(...)
@@ -417,16 +435,16 @@ extern "C" rocsparse_status rocsparse_ccsr2hyb(rocsparse_handle               ha
                                                rocsparse_hyb_partition        partition_type)
 try
 {
-    RETURN_IF_ROCSPARSE_ERROR(rocsparse_csr2hyb_template(handle,
-                                                         m,
-                                                         n,
-                                                         descr,
-                                                         csr_val,
-                                                         csr_row_ptr,
-                                                         csr_col_ind,
-                                                         hyb,
-                                                         user_ell_width,
-                                                         partition_type));
+    RETURN_IF_ROCSPARSE_ERROR(rocsparse::csr2hyb_template(handle,
+                                                          m,
+                                                          n,
+                                                          descr,
+                                                          csr_val,
+                                                          csr_row_ptr,
+                                                          csr_col_ind,
+                                                          hyb,
+                                                          user_ell_width,
+                                                          partition_type));
     return rocsparse_status_success;
 }
 catch(...)
@@ -446,16 +464,16 @@ extern "C" rocsparse_status rocsparse_zcsr2hyb(rocsparse_handle                h
                                                rocsparse_hyb_partition         partition_type)
 try
 {
-    RETURN_IF_ROCSPARSE_ERROR(rocsparse_csr2hyb_template(handle,
-                                                         m,
-                                                         n,
-                                                         descr,
-                                                         csr_val,
-                                                         csr_row_ptr,
-                                                         csr_col_ind,
-                                                         hyb,
-                                                         user_ell_width,
-                                                         partition_type));
+    RETURN_IF_ROCSPARSE_ERROR(rocsparse::csr2hyb_template(handle,
+                                                          m,
+                                                          n,
+                                                          descr,
+                                                          csr_val,
+                                                          csr_row_ptr,
+                                                          csr_col_ind,
+                                                          hyb,
+                                                          user_ell_width,
+                                                          partition_type));
     return rocsparse_status_success;
 }
 catch(...)
