@@ -1,6 +1,6 @@
 /*! \file */
 /* ************************************************************************
- * Copyright (C) 2018-2023 Advanced Micro Devices, Inc. All rights Reserved.
+ * Copyright (C) 2018-2024 Advanced Micro Devices, Inc. All rights Reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -23,24 +23,24 @@
  * ************************************************************************ */
 
 #include "internal/conversion/rocsparse_ell2csr.h"
-#include "definitions.h"
+#include "control.h"
 #include "rocsparse_ell2csr.hpp"
 #include "utility.h"
 
 #include "ell2csr_device.h"
 #include <rocprim/rocprim.hpp>
 
-rocsparse_status rocsparse_ell2csr_quickreturn(rocsparse_handle          handle,
-                                               int64_t                   m,
-                                               int64_t                   n,
-                                               const rocsparse_mat_descr ell_descr,
-                                               int64_t                   ell_width,
-                                               const void*               ell_val,
-                                               const void*               ell_col_ind,
-                                               const rocsparse_mat_descr csr_descr,
-                                               void*                     csr_val,
-                                               const void*               csr_row_ptr,
-                                               void*                     csr_col_ind)
+rocsparse_status rocsparse::ell2csr_quickreturn(rocsparse_handle          handle,
+                                                int64_t                   m,
+                                                int64_t                   n,
+                                                const rocsparse_mat_descr ell_descr,
+                                                int64_t                   ell_width,
+                                                const void*               ell_val,
+                                                const void*               ell_col_ind,
+                                                const rocsparse_mat_descr csr_descr,
+                                                void*                     csr_val,
+                                                const void*               csr_row_ptr,
+                                                void*                     csr_col_ind)
 {
     if(m == 0 || n == 0 || ell_width == 0)
     {
@@ -49,17 +49,17 @@ rocsparse_status rocsparse_ell2csr_quickreturn(rocsparse_handle          handle,
     return rocsparse_status_continue;
 }
 
-rocsparse_status rocsparse_ell2csr_checkarg(rocsparse_handle          handle, //0
-                                            int64_t                   m, //1
-                                            int64_t                   n, //2
-                                            const rocsparse_mat_descr ell_descr, //3
-                                            int64_t                   ell_width, //4
-                                            const void*               ell_val, //5
-                                            const void*               ell_col_ind, //6
-                                            const rocsparse_mat_descr csr_descr, //7
-                                            void*                     csr_val, //8
-                                            const void*               csr_row_ptr, //9
-                                            void*                     csr_col_ind) //10
+rocsparse_status rocsparse::ell2csr_checkarg(rocsparse_handle          handle, //0
+                                             int64_t                   m, //1
+                                             int64_t                   n, //2
+                                             const rocsparse_mat_descr ell_descr, //3
+                                             int64_t                   ell_width, //4
+                                             const void*               ell_val, //5
+                                             const void*               ell_col_ind, //6
+                                             const rocsparse_mat_descr csr_descr, //7
+                                             void*                     csr_val, //8
+                                             const void*               csr_row_ptr, //9
+                                             void*                     csr_col_ind) //10
 {
     ROCSPARSE_CHECKARG_HANDLE(0, handle);
     ROCSPARSE_CHECKARG_SIZE(1, m);
@@ -84,17 +84,17 @@ rocsparse_status rocsparse_ell2csr_checkarg(rocsparse_handle          handle, //
                        (csr_descr->storage_mode != rocsparse_storage_mode_sorted),
                        rocsparse_status_requires_sorted_storage);
 
-    const rocsparse_status status = rocsparse_ell2csr_quickreturn(handle,
-                                                                  m,
-                                                                  n,
-                                                                  ell_descr,
-                                                                  ell_width,
-                                                                  ell_val,
-                                                                  ell_col_ind,
-                                                                  csr_descr,
-                                                                  csr_val,
-                                                                  csr_row_ptr,
-                                                                  csr_col_ind);
+    const rocsparse_status status = rocsparse::ell2csr_quickreturn(handle,
+                                                                   m,
+                                                                   n,
+                                                                   ell_descr,
+                                                                   ell_width,
+                                                                   ell_val,
+                                                                   ell_col_ind,
+                                                                   csr_descr,
+                                                                   csr_val,
+                                                                   csr_row_ptr,
+                                                                   csr_col_ind);
 
     if(status != rocsparse_status_continue)
     {
@@ -115,17 +115,17 @@ rocsparse_status rocsparse_ell2csr_checkarg(rocsparse_handle          handle, //
 }
 
 template <typename T, typename I, typename J>
-rocsparse_status rocsparse_ell2csr_core(rocsparse_handle          handle,
-                                        J                         m,
-                                        J                         n,
-                                        const rocsparse_mat_descr ell_descr,
-                                        J                         ell_width,
-                                        const T*                  ell_val,
-                                        const J*                  ell_col_ind,
-                                        const rocsparse_mat_descr csr_descr,
-                                        T*                        csr_val,
-                                        const I*                  csr_row_ptr,
-                                        J*                        csr_col_ind)
+rocsparse_status rocsparse::ell2csr_core(rocsparse_handle          handle,
+                                         J                         m,
+                                         J                         n,
+                                         const rocsparse_mat_descr ell_descr,
+                                         J                         ell_width,
+                                         const T*                  ell_val,
+                                         const J*                  ell_col_ind,
+                                         const rocsparse_mat_descr csr_descr,
+                                         T*                        csr_val,
+                                         const I*                  csr_row_ptr,
+                                         J*                        csr_col_ind)
 {
     // Stream
     hipStream_t stream = handle->stream;
@@ -133,7 +133,7 @@ rocsparse_status rocsparse_ell2csr_core(rocsparse_handle          handle,
     dim3 ell2csr_blocks((m - 1) / ELL2CSR_DIM + 1);
     dim3 ell2csr_threads(ELL2CSR_DIM);
 
-    RETURN_IF_HIPLAUNCHKERNELGGL_ERROR((ell2csr_fill<ELL2CSR_DIM>),
+    RETURN_IF_HIPLAUNCHKERNELGGL_ERROR((rocsparse::ell2csr_fill<ELL2CSR_DIM>),
                                        ell2csr_blocks,
                                        ell2csr_threads,
                                        0,
@@ -152,18 +152,19 @@ rocsparse_status rocsparse_ell2csr_core(rocsparse_handle          handle,
     return rocsparse_status_success;
 }
 
-#define INSTANTIATE(T, I, J)                                                                         \
-    template rocsparse_status rocsparse_ell2csr_core<T, I, J>(rocsparse_handle          handle,      \
-                                                              J                         m,           \
-                                                              J                         n,           \
-                                                              const rocsparse_mat_descr ell_descr,   \
-                                                              J                         ell_width,   \
-                                                              const T*                  ell_val,     \
-                                                              const J*                  ell_col_ind, \
-                                                              const rocsparse_mat_descr csr_descr,   \
-                                                              T*                        csr_val,     \
-                                                              const I*                  csr_row_ptr, \
-                                                              J*                        csr_col_ind)
+#define INSTANTIATE(T, I, J)                                    \
+    template rocsparse_status rocsparse::ell2csr_core<T, I, J>( \
+        rocsparse_handle          handle,                       \
+        J                         m,                            \
+        J                         n,                            \
+        const rocsparse_mat_descr ell_descr,                    \
+        J                         ell_width,                    \
+        const T*                  ell_val,                      \
+        const J*                  ell_col_ind,                  \
+        const rocsparse_mat_descr csr_descr,                    \
+        T*                        csr_val,                      \
+        const I*                  csr_row_ptr,                  \
+        J*                        csr_col_ind)
 
 INSTANTIATE(float, int32_t, int32_t);
 INSTANTIATE(rocsparse_float_complex, int32_t, int32_t);
@@ -193,15 +194,15 @@ INSTANTIATE(rocsparse_double_complex, int64_t, int64_t);
  * ===========================================================================
  */
 
-rocsparse_status rocsparse_ell2csr_nnz_quickreturn(rocsparse_handle          handle,
-                                                   int64_t                   m,
-                                                   int64_t                   n,
-                                                   const rocsparse_mat_descr ell_descr,
-                                                   int64_t                   ell_width,
-                                                   const void*               ell_col_ind,
-                                                   const rocsparse_mat_descr csr_descr,
-                                                   void*                     csr_row_ptr,
-                                                   void*                     csr_nnz)
+rocsparse_status rocsparse::ell2csr_nnz_quickreturn(rocsparse_handle          handle,
+                                                    int64_t                   m,
+                                                    int64_t                   n,
+                                                    const rocsparse_mat_descr ell_descr,
+                                                    int64_t                   ell_width,
+                                                    const void*               ell_col_ind,
+                                                    const rocsparse_mat_descr csr_descr,
+                                                    void*                     csr_row_ptr,
+                                                    void*                     csr_nnz)
 {
     if(m == 0 || n == 0 || ell_width == 0)
     {
@@ -210,15 +211,15 @@ rocsparse_status rocsparse_ell2csr_nnz_quickreturn(rocsparse_handle          han
     return rocsparse_status_continue;
 }
 
-rocsparse_status rocsparse_ell2csr_nnz_checkarg(rocsparse_handle          handle,
-                                                int64_t                   m,
-                                                int64_t                   n,
-                                                const rocsparse_mat_descr ell_descr,
-                                                int64_t                   ell_width,
-                                                const void*               ell_col_ind,
-                                                const rocsparse_mat_descr csr_descr,
-                                                void*                     csr_row_ptr,
-                                                void*                     csr_nnz)
+rocsparse_status rocsparse::ell2csr_nnz_checkarg(rocsparse_handle          handle,
+                                                 int64_t                   m,
+                                                 int64_t                   n,
+                                                 const rocsparse_mat_descr ell_descr,
+                                                 int64_t                   ell_width,
+                                                 const void*               ell_col_ind,
+                                                 const rocsparse_mat_descr csr_descr,
+                                                 void*                     csr_row_ptr,
+                                                 void*                     csr_nnz)
 
 {
     ROCSPARSE_CHECKARG_HANDLE(0, handle);
@@ -247,7 +248,7 @@ rocsparse_status rocsparse_ell2csr_nnz_checkarg(rocsparse_handle          handle
     ROCSPARSE_CHECKARG_ARRAY(5, ell_width * m, ell_col_ind);
     ROCSPARSE_CHECKARG_ARRAY(7, m, csr_row_ptr);
 
-    const rocsparse_status status = rocsparse_ell2csr_nnz_quickreturn(
+    const rocsparse_status status = rocsparse::ell2csr_nnz_quickreturn(
         handle, m, n, ell_descr, ell_width, ell_col_ind, csr_descr, csr_row_ptr, csr_nnz);
 
     if(status != rocsparse_status_continue)
@@ -260,22 +261,22 @@ rocsparse_status rocsparse_ell2csr_nnz_checkarg(rocsparse_handle          handle
 }
 
 template <typename I, typename J>
-rocsparse_status rocsparse_ell2csr_nnz_core(rocsparse_handle          handle,
-                                            J                         m,
-                                            J                         n,
-                                            const rocsparse_mat_descr ell_descr,
-                                            J                         ell_width,
-                                            const J*                  ell_col_ind,
-                                            const rocsparse_mat_descr csr_descr,
-                                            I*                        csr_row_ptr,
-                                            I*                        csr_nnz)
+rocsparse_status rocsparse::ell2csr_nnz_core(rocsparse_handle          handle,
+                                             J                         m,
+                                             J                         n,
+                                             const rocsparse_mat_descr ell_descr,
+                                             J                         ell_width,
+                                             const J*                  ell_col_ind,
+                                             const rocsparse_mat_descr csr_descr,
+                                             I*                        csr_row_ptr,
+                                             I*                        csr_nnz)
 {
     hipStream_t stream = handle->stream;
     // Count nnz per row
 #define ELL2CSR_DIM 256
     dim3 ell2csr_blocks((m + 1) / ELL2CSR_DIM + 1);
     dim3 ell2csr_threads(ELL2CSR_DIM);
-    RETURN_IF_HIPLAUNCHKERNELGGL_ERROR((ell2csr_nnz_per_row<ELL2CSR_DIM>),
+    RETURN_IF_HIPLAUNCHKERNELGGL_ERROR((rocsparse::ell2csr_nnz_per_row<ELL2CSR_DIM>),
                                        ell2csr_blocks,
                                        ell2csr_threads,
                                        0,
@@ -361,16 +362,16 @@ rocsparse_status rocsparse_ell2csr_nnz_core(rocsparse_handle          handle,
     return rocsparse_status_success;
 }
 
-#define INSTANTIATE(I, J)                                       \
-    template rocsparse_status rocsparse_ell2csr_nnz_core<I, J>( \
-        rocsparse_handle          handle,                       \
-        J                         m,                            \
-        J                         n,                            \
-        const rocsparse_mat_descr ell_descr,                    \
-        J                         ell_width,                    \
-        const J*                  ell_col_ind,                  \
-        const rocsparse_mat_descr csr_descr,                    \
-        I*                        csr_row_ptr,                  \
+#define INSTANTIATE(I, J)                                        \
+    template rocsparse_status rocsparse::ell2csr_nnz_core<I, J>( \
+        rocsparse_handle          handle,                        \
+        J                         m,                             \
+        J                         n,                             \
+        const rocsparse_mat_descr ell_descr,                     \
+        J                         ell_width,                     \
+        const J*                  ell_col_ind,                   \
+        const rocsparse_mat_descr csr_descr,                     \
+        I*                        csr_row_ptr,                   \
         I*                        csr_nnz)
 
 INSTANTIATE(int32_t, int32_t);
@@ -391,7 +392,7 @@ extern "C" rocsparse_status rocsparse_ell2csr_nnz(rocsparse_handle          hand
                                                   rocsparse_int*            csr_nnz)
 try
 {
-    RETURN_IF_ROCSPARSE_ERROR(rocsparse_ell2csr_nnz_impl(
+    RETURN_IF_ROCSPARSE_ERROR(rocsparse::ell2csr_nnz_impl(
         handle, m, n, ell_descr, ell_width, ell_col_ind, csr_descr, csr_row_ptr, csr_nnz));
     return rocsparse_status_success;
 }
@@ -413,17 +414,17 @@ extern "C" rocsparse_status rocsparse_sell2csr(rocsparse_handle          handle,
                                                rocsparse_int*            csr_col_ind)
 try
 {
-    RETURN_IF_ROCSPARSE_ERROR(rocsparse_ell2csr_impl(handle,
-                                                     m,
-                                                     n,
-                                                     ell_descr,
-                                                     ell_width,
-                                                     ell_val,
-                                                     ell_col_ind,
-                                                     csr_descr,
-                                                     csr_val,
-                                                     csr_row_ptr,
-                                                     csr_col_ind));
+    RETURN_IF_ROCSPARSE_ERROR(rocsparse::ell2csr_impl(handle,
+                                                      m,
+                                                      n,
+                                                      ell_descr,
+                                                      ell_width,
+                                                      ell_val,
+                                                      ell_col_ind,
+                                                      csr_descr,
+                                                      csr_val,
+                                                      csr_row_ptr,
+                                                      csr_col_ind));
     return rocsparse_status_success;
 }
 catch(...)
@@ -444,17 +445,17 @@ extern "C" rocsparse_status rocsparse_dell2csr(rocsparse_handle          handle,
                                                rocsparse_int*            csr_col_ind)
 try
 {
-    RETURN_IF_ROCSPARSE_ERROR(rocsparse_ell2csr_impl(handle,
-                                                     m,
-                                                     n,
-                                                     ell_descr,
-                                                     ell_width,
-                                                     ell_val,
-                                                     ell_col_ind,
-                                                     csr_descr,
-                                                     csr_val,
-                                                     csr_row_ptr,
-                                                     csr_col_ind));
+    RETURN_IF_ROCSPARSE_ERROR(rocsparse::ell2csr_impl(handle,
+                                                      m,
+                                                      n,
+                                                      ell_descr,
+                                                      ell_width,
+                                                      ell_val,
+                                                      ell_col_ind,
+                                                      csr_descr,
+                                                      csr_val,
+                                                      csr_row_ptr,
+                                                      csr_col_ind));
     return rocsparse_status_success;
 }
 catch(...)
@@ -475,17 +476,17 @@ extern "C" rocsparse_status rocsparse_cell2csr(rocsparse_handle               ha
                                                rocsparse_int*                 csr_col_ind)
 try
 {
-    RETURN_IF_ROCSPARSE_ERROR(rocsparse_ell2csr_impl(handle,
-                                                     m,
-                                                     n,
-                                                     ell_descr,
-                                                     ell_width,
-                                                     ell_val,
-                                                     ell_col_ind,
-                                                     csr_descr,
-                                                     csr_val,
-                                                     csr_row_ptr,
-                                                     csr_col_ind));
+    RETURN_IF_ROCSPARSE_ERROR(rocsparse::ell2csr_impl(handle,
+                                                      m,
+                                                      n,
+                                                      ell_descr,
+                                                      ell_width,
+                                                      ell_val,
+                                                      ell_col_ind,
+                                                      csr_descr,
+                                                      csr_val,
+                                                      csr_row_ptr,
+                                                      csr_col_ind));
     return rocsparse_status_success;
 }
 catch(...)
@@ -506,17 +507,17 @@ extern "C" rocsparse_status rocsparse_zell2csr(rocsparse_handle                h
                                                rocsparse_int*                  csr_col_ind)
 try
 {
-    RETURN_IF_ROCSPARSE_ERROR(rocsparse_ell2csr_impl(handle,
-                                                     m,
-                                                     n,
-                                                     ell_descr,
-                                                     ell_width,
-                                                     ell_val,
-                                                     ell_col_ind,
-                                                     csr_descr,
-                                                     csr_val,
-                                                     csr_row_ptr,
-                                                     csr_col_ind));
+    RETURN_IF_ROCSPARSE_ERROR(rocsparse::ell2csr_impl(handle,
+                                                      m,
+                                                      n,
+                                                      ell_descr,
+                                                      ell_width,
+                                                      ell_val,
+                                                      ell_col_ind,
+                                                      csr_descr,
+                                                      csr_val,
+                                                      csr_row_ptr,
+                                                      csr_col_ind));
     return rocsparse_status_success;
 }
 catch(...)
