@@ -1,6 +1,6 @@
 /*! \file */
 /* ************************************************************************
-* Copyright (C) 2020-2023 Advanced Micro Devices, Inc. All rights Reserved.
+* Copyright (C) 2020-2024 Advanced Micro Devices, Inc. All rights Reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
@@ -23,7 +23,7 @@
 * ************************************************************************ */
 
 #include "internal/conversion/rocsparse_prune_dense2csr.h"
-#include "definitions.h"
+#include "control.h"
 #include "rocsparse_prune_dense2csr.hpp"
 #include "utility.h"
 
@@ -31,64 +31,67 @@
 #include "prune_dense2csr_device.h"
 #include <rocprim/rocprim.hpp>
 
-template <rocsparse_int DIM_X, rocsparse_int DIM_Y, typename T, typename U>
-ROCSPARSE_KERNEL(DIM_X* DIM_Y)
-void prune_dense2csr_nnz_kernel(rocsparse_int m,
-                                rocsparse_int n,
+namespace rocsparse
+{
+    template <rocsparse_int DIM_X, rocsparse_int DIM_Y, typename T, typename U>
+    ROCSPARSE_KERNEL(DIM_X* DIM_Y)
+    void prune_dense2csr_nnz_kernel(rocsparse_int m,
+                                    rocsparse_int n,
+                                    const T* __restrict__ A,
+                                    int64_t lda,
+                                    U       threshold_device_host,
+                                    rocsparse_int* __restrict__ nnz_per_rows)
+    {
+        auto threshold = rocsparse::load_scalar_device_host(threshold_device_host);
+        rocsparse::prune_dense2csr_nnz_device<DIM_X, DIM_Y>(m, n, A, lda, threshold, nnz_per_rows);
+    }
+
+    template <rocsparse_int NUMROWS_PER_BLOCK, rocsparse_int WF_SIZE, typename T, typename U>
+    ROCSPARSE_KERNEL(WF_SIZE* NUMROWS_PER_BLOCK)
+    void prune_dense2csr_kernel(rocsparse_index_base base,
+                                rocsparse_int        m,
+                                rocsparse_int        n,
                                 const T* __restrict__ A,
                                 int64_t lda,
                                 U       threshold_device_host,
-                                rocsparse_int* __restrict__ nnz_per_rows)
-{
-    auto threshold = load_scalar_device_host(threshold_device_host);
-    prune_dense2csr_nnz_device<DIM_X, DIM_Y>(m, n, A, lda, threshold, nnz_per_rows);
-}
-
-template <rocsparse_int NUMROWS_PER_BLOCK, rocsparse_int WF_SIZE, typename T, typename U>
-ROCSPARSE_KERNEL(WF_SIZE* NUMROWS_PER_BLOCK)
-void prune_dense2csr_kernel(rocsparse_index_base base,
-                            rocsparse_int        m,
-                            rocsparse_int        n,
-                            const T* __restrict__ A,
-                            int64_t lda,
-                            U       threshold_device_host,
-                            T* __restrict__ csr_val,
-                            const rocsparse_int* __restrict__ csr_row_ptr,
-                            rocsparse_int* __restrict__ csr_col_ind)
-{
-    auto threshold = load_scalar_device_host(threshold_device_host);
-    prune_dense2csr_device<NUMROWS_PER_BLOCK, WF_SIZE>(
-        base, m, n, A, lda, threshold, csr_val, csr_row_ptr, csr_col_ind);
+                                T* __restrict__ csr_val,
+                                const rocsparse_int* __restrict__ csr_row_ptr,
+                                rocsparse_int* __restrict__ csr_col_ind)
+    {
+        auto threshold = rocsparse::load_scalar_device_host(threshold_device_host);
+        rocsparse::prune_dense2csr_device<NUMROWS_PER_BLOCK, WF_SIZE>(
+            base, m, n, A, lda, threshold, csr_val, csr_row_ptr, csr_col_ind);
+    }
 }
 
 template <typename T>
 rocsparse_status
-    rocsparse_prune_dense2csr_buffer_size_template(rocsparse_handle          handle, //0
-                                                   rocsparse_int             m, //1
-                                                   rocsparse_int             n, //2
-                                                   const T*                  A, //3
-                                                   int64_t                   lda, //4
-                                                   const T*                  threshold, //5
-                                                   const rocsparse_mat_descr descr, //6
-                                                   const T*                  csr_val, //7
-                                                   const rocsparse_int*      csr_row_ptr, //8
-                                                   const rocsparse_int*      csr_col_ind, //9
-                                                   size_t*                   buffer_size) //10
+    rocsparse::prune_dense2csr_buffer_size_template(rocsparse_handle          handle, //0
+                                                    rocsparse_int             m, //1
+                                                    rocsparse_int             n, //2
+                                                    const T*                  A, //3
+                                                    int64_t                   lda, //4
+                                                    const T*                  threshold, //5
+                                                    const rocsparse_mat_descr descr, //6
+                                                    const T*                  csr_val, //7
+                                                    const rocsparse_int*      csr_row_ptr, //8
+                                                    const rocsparse_int*      csr_col_ind, //9
+                                                    size_t*                   buffer_size) //10
 {
 
     // Logging
-    log_trace(handle,
-              replaceX<T>("rocsparse_Xprune_dense2csr_buffer_size"),
-              m,
-              n,
-              (const void*&)A,
-              lda,
-              (const void*&)threshold,
-              descr,
-              (const void*&)csr_val,
-              (const void*&)csr_row_ptr,
-              (const void*&)csr_col_ind,
-              (const void*&)buffer_size);
+    rocsparse::log_trace(handle,
+                         rocsparse::replaceX<T>("rocsparse_Xprune_dense2csr_buffer_size"),
+                         m,
+                         n,
+                         (const void*&)A,
+                         lda,
+                         (const void*&)threshold,
+                         descr,
+                         (const void*&)csr_val,
+                         (const void*&)csr_row_ptr,
+                         (const void*&)csr_col_ind,
+                         (const void*&)buffer_size);
 
     ROCSPARSE_CHECKARG_HANDLE(0, handle);
     ROCSPARSE_CHECKARG_SIZE(1, m);
@@ -110,30 +113,30 @@ rocsparse_status
 }
 
 template <typename T>
-rocsparse_status rocsparse_prune_dense2csr_nnz_template(rocsparse_handle          handle, //0
-                                                        rocsparse_int             m, //1
-                                                        rocsparse_int             n, //2
-                                                        const T*                  A, //3
-                                                        int64_t                   lda, //4
-                                                        const T*                  threshold, //5
-                                                        const rocsparse_mat_descr descr, //6
-                                                        rocsparse_int*            csr_row_ptr, //7
-                                                        rocsparse_int* nnz_total_dev_host_ptr, //8
-                                                        void*          temp_buffer) //9
+rocsparse_status rocsparse::prune_dense2csr_nnz_template(rocsparse_handle          handle, //0
+                                                         rocsparse_int             m, //1
+                                                         rocsparse_int             n, //2
+                                                         const T*                  A, //3
+                                                         int64_t                   lda, //4
+                                                         const T*                  threshold, //5
+                                                         const rocsparse_mat_descr descr, //6
+                                                         rocsparse_int*            csr_row_ptr, //7
+                                                         rocsparse_int* nnz_total_dev_host_ptr, //8
+                                                         void*          temp_buffer) //9
 {
 
     // Logging
-    log_trace(handle,
-              replaceX<T>("rocsparse_Xprune_dense2csr_nnz"),
-              m,
-              n,
-              (const void*&)A,
-              lda,
-              (const void*&)threshold,
-              descr,
-              (const void*&)csr_row_ptr,
-              (const void*&)nnz_total_dev_host_ptr,
-              (const void*&)temp_buffer);
+    rocsparse::log_trace(handle,
+                         rocsparse::replaceX<T>("rocsparse_Xprune_dense2csr_nnz"),
+                         m,
+                         n,
+                         (const void*&)A,
+                         lda,
+                         (const void*&)threshold,
+                         descr,
+                         (const void*&)csr_row_ptr,
+                         (const void*&)nnz_total_dev_host_ptr,
+                         (const void*&)temp_buffer);
 
     ROCSPARSE_CHECKARG_HANDLE(0, handle);
     ROCSPARSE_CHECKARG_SIZE(1, m);
@@ -158,7 +161,7 @@ rocsparse_status rocsparse_prune_dense2csr_nnz_template(rocsparse_handle
     {
         if(nnz_total_dev_host_ptr != nullptr && csr_row_ptr != nullptr)
         {
-            RETURN_IF_HIPLAUNCHKERNELGGL_ERROR((set_array_to_value<256>),
+            RETURN_IF_HIPLAUNCHKERNELGGL_ERROR((rocsparse::set_array_to_value<256>),
                                                dim3(m / 256 + 1),
                                                dim3(256),
                                                0,
@@ -193,31 +196,33 @@ rocsparse_status rocsparse_prune_dense2csr_nnz_template(rocsparse_handle
 
     if(handle->pointer_mode == rocsparse_pointer_mode_device)
     {
-        RETURN_IF_HIPLAUNCHKERNELGGL_ERROR((prune_dense2csr_nnz_kernel<NNZ_DIM_X, NNZ_DIM_Y, T>),
-                                           grid,
-                                           threads,
-                                           0,
-                                           stream,
-                                           m,
-                                           n,
-                                           A,
-                                           lda,
-                                           threshold,
-                                           &csr_row_ptr[1]);
+        RETURN_IF_HIPLAUNCHKERNELGGL_ERROR(
+            (rocsparse::prune_dense2csr_nnz_kernel<NNZ_DIM_X, NNZ_DIM_Y, T>),
+            grid,
+            threads,
+            0,
+            stream,
+            m,
+            n,
+            A,
+            lda,
+            threshold,
+            &csr_row_ptr[1]);
     }
     else
     {
-        RETURN_IF_HIPLAUNCHKERNELGGL_ERROR((prune_dense2csr_nnz_kernel<NNZ_DIM_X, NNZ_DIM_Y, T>),
-                                           grid,
-                                           threads,
-                                           0,
-                                           stream,
-                                           m,
-                                           n,
-                                           A,
-                                           lda,
-                                           *threshold,
-                                           &csr_row_ptr[1]);
+        RETURN_IF_HIPLAUNCHKERNELGGL_ERROR(
+            (rocsparse::prune_dense2csr_nnz_kernel<NNZ_DIM_X, NNZ_DIM_Y, T>),
+            grid,
+            threads,
+            0,
+            stream,
+            m,
+            n,
+            A,
+            lda,
+            *threshold,
+            &csr_row_ptr[1]);
     }
 
     // Compute csr_row_ptr with the right index base.
@@ -271,7 +276,7 @@ rocsparse_status rocsparse_prune_dense2csr_nnz_template(rocsparse_handle
     // Extract nnz_total_dev_host_ptr
     if(handle->pointer_mode == rocsparse_pointer_mode_device)
     {
-        RETURN_IF_HIPLAUNCHKERNELGGL_ERROR(nnz_total_device_kernel,
+        RETURN_IF_HIPLAUNCHKERNELGGL_ERROR(rocsparse::nnz_total_device_kernel,
                                            dim3(1),
                                            dim3(1),
                                            0,
@@ -296,32 +301,32 @@ rocsparse_status rocsparse_prune_dense2csr_nnz_template(rocsparse_handle
 }
 
 template <typename T>
-rocsparse_status rocsparse_prune_dense2csr_template(rocsparse_handle          handle, //0
-                                                    rocsparse_int             m, //1
-                                                    rocsparse_int             n, //2
-                                                    const T*                  A, //3
-                                                    int64_t                   lda, //4
-                                                    const T*                  threshold, //5
-                                                    const rocsparse_mat_descr descr, //6
-                                                    T*                        csr_val, //7
-                                                    const rocsparse_int*      csr_row_ptr, //8
-                                                    rocsparse_int*            csr_col_ind, //9
-                                                    void*                     temp_buffer) //10
+rocsparse_status rocsparse::prune_dense2csr_template(rocsparse_handle          handle, //0
+                                                     rocsparse_int             m, //1
+                                                     rocsparse_int             n, //2
+                                                     const T*                  A, //3
+                                                     int64_t                   lda, //4
+                                                     const T*                  threshold, //5
+                                                     const rocsparse_mat_descr descr, //6
+                                                     T*                        csr_val, //7
+                                                     const rocsparse_int*      csr_row_ptr, //8
+                                                     rocsparse_int*            csr_col_ind, //9
+                                                     void*                     temp_buffer) //10
 {
 
     // Logging
-    log_trace(handle,
-              replaceX<T>("rocsparse_Xprune_dense2csr"),
-              m,
-              n,
-              (const void*&)A,
-              lda,
-              (const void*&)threshold,
-              descr,
-              (const void*&)csr_val,
-              (const void*&)csr_row_ptr,
-              (const void*&)csr_col_ind,
-              (const void*&)temp_buffer);
+    rocsparse::log_trace(handle,
+                         rocsparse::replaceX<T>("rocsparse_Xprune_dense2csr"),
+                         m,
+                         n,
+                         (const void*&)A,
+                         lda,
+                         (const void*&)threshold,
+                         descr,
+                         (const void*&)csr_val,
+                         (const void*&)csr_row_ptr,
+                         (const void*&)csr_col_ind,
+                         (const void*&)temp_buffer);
 
     ROCSPARSE_CHECKARG_HANDLE(0, handle);
     ROCSPARSE_CHECKARG_SIZE(1, m);
@@ -376,7 +381,7 @@ rocsparse_status rocsparse_prune_dense2csr_template(rocsparse_handle          ha
         if(handle->pointer_mode == rocsparse_pointer_mode_device)
         {
             RETURN_IF_HIPLAUNCHKERNELGGL_ERROR(
-                (prune_dense2csr_kernel<NROWS_PER_BLOCK, WF_SIZE, T>),
+                (rocsparse::prune_dense2csr_kernel<NROWS_PER_BLOCK, WF_SIZE, T>),
                 blocks,
                 threads,
                 0,
@@ -394,7 +399,7 @@ rocsparse_status rocsparse_prune_dense2csr_template(rocsparse_handle          ha
         else
         {
             RETURN_IF_HIPLAUNCHKERNELGGL_ERROR(
-                (prune_dense2csr_kernel<NROWS_PER_BLOCK, WF_SIZE, T>),
+                (rocsparse::prune_dense2csr_kernel<NROWS_PER_BLOCK, WF_SIZE, T>),
                 blocks,
                 threads,
                 0,
@@ -420,7 +425,7 @@ rocsparse_status rocsparse_prune_dense2csr_template(rocsparse_handle          ha
         if(handle->pointer_mode == rocsparse_pointer_mode_device)
         {
             RETURN_IF_HIPLAUNCHKERNELGGL_ERROR(
-                (prune_dense2csr_kernel<NROWS_PER_BLOCK, WF_SIZE, T>),
+                (rocsparse::prune_dense2csr_kernel<NROWS_PER_BLOCK, WF_SIZE, T>),
                 blocks,
                 threads,
                 0,
@@ -438,7 +443,7 @@ rocsparse_status rocsparse_prune_dense2csr_template(rocsparse_handle          ha
         else
         {
             RETURN_IF_HIPLAUNCHKERNELGGL_ERROR(
-                (prune_dense2csr_kernel<NROWS_PER_BLOCK, WF_SIZE, T>),
+                (rocsparse::prune_dense2csr_kernel<NROWS_PER_BLOCK, WF_SIZE, T>),
                 blocks,
                 threads,
                 0,
@@ -477,7 +482,7 @@ extern "C" rocsparse_status rocsparse_sprune_dense2csr_buffer_size(rocsparse_han
                                                                    size_t*              buffer_size)
 try
 {
-    RETURN_IF_ROCSPARSE_ERROR(rocsparse_prune_dense2csr_buffer_size_template(
+    RETURN_IF_ROCSPARSE_ERROR(rocsparse::prune_dense2csr_buffer_size_template(
         handle, m, n, A, lda, threshold, descr, csr_val, csr_row_ptr, csr_col_ind, buffer_size));
     return rocsparse_status_success;
 }
@@ -499,7 +504,7 @@ extern "C" rocsparse_status rocsparse_dprune_dense2csr_buffer_size(rocsparse_han
                                                                    size_t*              buffer_size)
 try
 {
-    RETURN_IF_ROCSPARSE_ERROR(rocsparse_prune_dense2csr_buffer_size_template(
+    RETURN_IF_ROCSPARSE_ERROR(rocsparse::prune_dense2csr_buffer_size_template(
         handle, m, n, A, lda, threshold, descr, csr_val, csr_row_ptr, csr_col_ind, buffer_size));
     return rocsparse_status_success;
 }
@@ -520,7 +525,7 @@ extern "C" rocsparse_status rocsparse_sprune_dense2csr_nnz(rocsparse_handle
                                                            void*          temp_buffer)
 try
 {
-    RETURN_IF_ROCSPARSE_ERROR(rocsparse_prune_dense2csr_nnz_template(
+    RETURN_IF_ROCSPARSE_ERROR(rocsparse::prune_dense2csr_nnz_template(
         handle, m, n, A, lda, threshold, descr, csr_row_ptr, nnz_total_dev_host_ptr, temp_buffer));
     return rocsparse_status_success;
 }
@@ -541,7 +546,7 @@ extern "C" rocsparse_status rocsparse_dprune_dense2csr_nnz(rocsparse_handle
                                                            void*          temp_buffer)
 try
 {
-    RETURN_IF_ROCSPARSE_ERROR(rocsparse_prune_dense2csr_nnz_template(
+    RETURN_IF_ROCSPARSE_ERROR(rocsparse::prune_dense2csr_nnz_template(
         handle, m, n, A, lda, threshold, descr, csr_row_ptr, nnz_total_dev_host_ptr, temp_buffer));
     return rocsparse_status_success;
 }
@@ -563,7 +568,7 @@ extern "C" rocsparse_status rocsparse_sprune_dense2csr(rocsparse_handle
                                                        void*                     temp_buffer)
 try
 {
-    RETURN_IF_ROCSPARSE_ERROR(rocsparse_prune_dense2csr_template(
+    RETURN_IF_ROCSPARSE_ERROR(rocsparse::prune_dense2csr_template(
         handle, m, n, A, lda, threshold, descr, csr_val, csr_row_ptr, csr_col_ind, temp_buffer));
     return rocsparse_status_success;
 }
@@ -585,7 +590,7 @@ extern "C" rocsparse_status rocsparse_dprune_dense2csr(rocsparse_handle
                                                        void*                     temp_buffer)
 try
 {
-    RETURN_IF_ROCSPARSE_ERROR(rocsparse_prune_dense2csr_template(
+    RETURN_IF_ROCSPARSE_ERROR(rocsparse::prune_dense2csr_template(
         handle, m, n, A, lda, threshold, descr, csr_val, csr_row_ptr, csr_col_ind, temp_buffer));
     return rocsparse_status_success;
 }
