@@ -1,5 +1,5 @@
 /* ************************************************************************
- * Copyright (C) 2018-2023 Advanced Micro Devices, Inc. All rights Reserved.
+ * Copyright (C) 2018-2024 Advanced Micro Devices, Inc. All rights Reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -22,7 +22,7 @@
  * ************************************************************************ */
 
 #include "handle.h"
-#include "definitions.h"
+#include "control.h"
 #include "logging.h"
 #include "utility.h"
 
@@ -103,41 +103,41 @@ _rocsparse_handle::_rocsparse_handle()
     THROW_IF_HIP_ERROR(hipStreamSynchronize(stream));
 
     // create blas handle
-    rocsparse_blas_impl blas_impl;
+    rocsparse::blas_impl blas_impl;
 
 #ifdef ROCSPARSE_WITH_ROCBLAS
 
-    blas_impl = rocsparse_blas_impl_rocblas;
+    blas_impl = rocsparse::blas_impl_rocblas;
 
 #else
 
     //
     // Other implementation available? Otherwise, set it to none.
     //
-    blas_impl = rocsparse_blas_impl_none;
+    blas_impl = rocsparse::blas_impl_none;
 #endif
 
-    THROW_IF_ROCSPARSE_ERROR(rocsparse_blas_create_handle(&this->blas_handle, blas_impl));
-    THROW_IF_ROCSPARSE_ERROR(rocsparse_blas_set_stream(this->blas_handle, this->stream));
+    THROW_IF_ROCSPARSE_ERROR(rocsparse::blas_create_handle(&this->blas_handle, blas_impl));
+    THROW_IF_ROCSPARSE_ERROR(rocsparse::blas_set_stream(this->blas_handle, this->stream));
     THROW_IF_ROCSPARSE_ERROR(
-        rocsparse_blas_set_pointer_mode(this->blas_handle, this->pointer_mode));
+        rocsparse::blas_set_pointer_mode(this->blas_handle, this->pointer_mode));
 
     // Open log file
     if(layer_mode & rocsparse_layer_mode_log_trace)
     {
-        open_log_stream(&log_trace_os, &log_trace_ofs, "ROCSPARSE_LOG_TRACE_PATH");
+        rocsparse::open_log_stream(&log_trace_os, &log_trace_ofs, "ROCSPARSE_LOG_TRACE_PATH");
     }
 
     // Open log_bench file
     if(layer_mode & rocsparse_layer_mode_log_bench)
     {
-        open_log_stream(&log_bench_os, &log_bench_ofs, "ROCSPARSE_LOG_BENCH_PATH");
+        rocsparse::open_log_stream(&log_bench_os, &log_bench_ofs, "ROCSPARSE_LOG_BENCH_PATH");
     }
 
     // Open log_debug file
     if(layer_mode & rocsparse_layer_mode_log_debug)
     {
-        open_log_stream(&log_debug_os, &log_debug_ofs, "ROCSPARSE_LOG_DEBUG_PATH");
+        rocsparse::open_log_stream(&log_debug_os, &log_debug_ofs, "ROCSPARSE_LOG_DEBUG_PATH");
     }
 }
 
@@ -153,7 +153,7 @@ _rocsparse_handle::~_rocsparse_handle()
     PRINT_IF_HIP_ERROR(rocsparse_hipFree(zone));
 
     // destroy blas handle
-    rocsparse_status status = rocsparse_blas_destroy_handle(this->blas_handle);
+    rocsparse_status status = rocsparse::blas_destroy_handle(this->blas_handle);
     if(status != rocsparse_status_success)
     {
         ROCSPARSE_ERROR_MESSAGE(status, "handle error");
@@ -189,7 +189,7 @@ rocsparse_status _rocsparse_handle::set_stream(hipStream_t user_stream)
     stream = user_stream;
 
     // blas set stream
-    RETURN_IF_ROCSPARSE_ERROR(rocsparse_blas_set_stream(this->blas_handle, user_stream));
+    RETURN_IF_ROCSPARSE_ERROR(rocsparse::blas_set_stream(this->blas_handle, user_stream));
 
     return rocsparse_status_success;
 }
@@ -212,7 +212,7 @@ rocsparse_status _rocsparse_handle::set_pointer_mode(rocsparse_pointer_mode user
     this->pointer_mode = user_mode;
 
     // blas set stream
-    RETURN_IF_ROCSPARSE_ERROR(rocsparse_blas_set_pointer_mode(this->blas_handle, user_mode));
+    RETURN_IF_ROCSPARSE_ERROR(rocsparse::blas_set_pointer_mode(this->blas_handle, user_mode));
 
     return rocsparse_status_success;
 }
@@ -229,10 +229,10 @@ rocsparse_status _rocsparse_handle::get_pointer_mode(rocsparse_pointer_mode* use
 /********************************************************************************
  * \brief rocsparse_csrmv_info is a structure holding the rocsparse csrmv info
  * data gathered during csrmv_analysis. It must be initialized using the
- * rocsparse_create_csrmv_info() routine. It should be destroyed at the end
- * using rocsparse_destroy_csrmv_info().
+ * create_csrmv_info() routine. It should be destroyed at the end
+ * using destroy_csrmv_info().
  *******************************************************************************/
-rocsparse_status rocsparse_create_csrmv_info(rocsparse_csrmv_info* info)
+rocsparse_status rocsparse::create_csrmv_info(rocsparse_csrmv_info* info)
 {
     if(info == nullptr)
     {
@@ -256,8 +256,8 @@ rocsparse_status rocsparse_create_csrmv_info(rocsparse_csrmv_info* info)
 /********************************************************************************
  * \brief Copy csrmv info.
  *******************************************************************************/
-rocsparse_status rocsparse_copy_csrmv_info(rocsparse_csrmv_info       dest,
-                                           const rocsparse_csrmv_info src)
+rocsparse_status rocsparse::copy_csrmv_info(rocsparse_csrmv_info       dest,
+                                            const rocsparse_csrmv_info src)
 {
     if(dest == nullptr || src == nullptr || dest == src)
     {
@@ -367,11 +367,11 @@ rocsparse_status rocsparse_copy_csrmv_info(rocsparse_csrmv_info       dest,
         if(dest->adaptive.wg_flags == nullptr)
         {
             RETURN_IF_HIP_ERROR(rocsparse_hipMalloc((void**)&dest->adaptive.wg_flags,
-                                                    sizeof(unsigned int) * src->adaptive.size));
+                                                    sizeof(uint32_t) * src->adaptive.size));
         }
         RETURN_IF_HIP_ERROR(hipMemcpy(dest->adaptive.wg_flags,
                                       src->adaptive.wg_flags,
-                                      sizeof(unsigned int) * src->adaptive.size,
+                                      sizeof(uint32_t) * src->adaptive.size,
                                       hipMemcpyDeviceToDevice));
     }
 
@@ -392,12 +392,12 @@ rocsparse_status rocsparse_copy_csrmv_info(rocsparse_csrmv_info       dest,
     {
         if(dest->lrb.wg_flags == nullptr)
         {
-            RETURN_IF_HIP_ERROR(rocsparse_hipMalloc((void**)&dest->lrb.wg_flags,
-                                                    sizeof(unsigned int) * src->lrb.size));
+            RETURN_IF_HIP_ERROR(
+                rocsparse_hipMalloc((void**)&dest->lrb.wg_flags, sizeof(uint32_t) * src->lrb.size));
         }
         RETURN_IF_HIP_ERROR(hipMemcpy(dest->lrb.wg_flags,
                                       src->lrb.wg_flags,
-                                      sizeof(unsigned int) * src->lrb.size,
+                                      sizeof(uint32_t) * src->lrb.size,
                                       hipMemcpyDeviceToDevice));
     }
 
@@ -455,7 +455,7 @@ rocsparse_status rocsparse_copy_csrmv_info(rocsparse_csrmv_info       dest,
 /********************************************************************************
  * \brief Destroy csrmv info.
  *******************************************************************************/
-rocsparse_status rocsparse_destroy_csrmv_info(rocsparse_csrmv_info info)
+rocsparse_status rocsparse::destroy_csrmv_info(rocsparse_csrmv_info info)
 {
     if(info == nullptr)
     {
@@ -499,10 +499,10 @@ rocsparse_status rocsparse_destroy_csrmv_info(rocsparse_csrmv_info info)
  * \brief rocsparse_trm_info is a structure holding the rocsparse bsrsv, csrsv,
  * csrsm, csrilu0 and csric0 data gathered during csrsv_analysis,
  * csrilu0_analysis and csric0_analysis. It must be initialized using the
- * rocsparse_create_trm_info() routine. It should be destroyed at the end
- * using rocsparse_destroy_trm_info().
+ * create_trm_info() routine. It should be destroyed at the end
+ * using destroy_trm_info().
  *******************************************************************************/
-rocsparse_status rocsparse_create_trm_info(rocsparse_trm_info* info)
+rocsparse_status rocsparse::create_trm_info(rocsparse_trm_info* info)
 {
     if(info == nullptr)
     {
@@ -526,7 +526,7 @@ rocsparse_status rocsparse_create_trm_info(rocsparse_trm_info* info)
 /********************************************************************************
  * \brief Copy trm info.
  *******************************************************************************/
-rocsparse_status rocsparse_copy_trm_info(rocsparse_trm_info dest, const rocsparse_trm_info src)
+rocsparse_status rocsparse::copy_trm_info(rocsparse_trm_info dest, const rocsparse_trm_info src)
 {
     if(dest == nullptr || src == nullptr || dest == src)
     {
@@ -677,7 +677,7 @@ rocsparse_status rocsparse_copy_trm_info(rocsparse_trm_info dest, const rocspars
 /********************************************************************************
  * \brief Destroy trm info.
  *******************************************************************************/
-rocsparse_status rocsparse_destroy_trm_info(rocsparse_trm_info info)
+rocsparse_status rocsparse::destroy_trm_info(rocsparse_trm_info info)
 {
     if(info == nullptr)
     {
@@ -729,10 +729,10 @@ rocsparse_status rocsparse_destroy_trm_info(rocsparse_trm_info info)
 }
 
 /********************************************************************************
- * \brief rocsparse_check_trm_shared checks if the given trm info structure
+ * \brief check_trm_shared checks if the given trm info structure
  * shares its meta data with another trm info structure.
  *******************************************************************************/
-bool rocsparse_check_trm_shared(const rocsparse_mat_info info, rocsparse_trm_info trm)
+bool rocsparse::check_trm_shared(const rocsparse_mat_info info, rocsparse_trm_info trm)
 {
     if(info == nullptr)
     {
@@ -780,10 +780,10 @@ bool rocsparse_check_trm_shared(const rocsparse_mat_info info, rocsparse_trm_inf
 /********************************************************************************
  * \brief rocsparse_csrgemm_info is a structure holding the rocsparse csrgemm
  * info data gathered during csrgemm_buffer_size. It must be initialized using
- * the rocsparse_create_csrgemm_info() routine. It should be destroyed at the
- * end using rocsparse_destroy_csrgemm_info().
+ * the create_csrgemm_info() routine. It should be destroyed at the
+ * end using destroy_csrgemm_info().
  *******************************************************************************/
-rocsparse_status rocsparse_create_csrgemm_info(rocsparse_csrgemm_info* info)
+rocsparse_status rocsparse::create_csrgemm_info(rocsparse_csrgemm_info* info)
 {
     if(info == nullptr)
     {
@@ -807,8 +807,8 @@ rocsparse_status rocsparse_create_csrgemm_info(rocsparse_csrgemm_info* info)
 /********************************************************************************
  * \brief Copy csrgemm info.
  *******************************************************************************/
-rocsparse_status rocsparse_copy_csrgemm_info(rocsparse_csrgemm_info       dest,
-                                             const rocsparse_csrgemm_info src)
+rocsparse_status rocsparse::copy_csrgemm_info(rocsparse_csrgemm_info       dest,
+                                              const rocsparse_csrgemm_info src)
 {
     if(dest == nullptr || src == nullptr || dest == src)
     {
@@ -824,7 +824,7 @@ rocsparse_status rocsparse_copy_csrgemm_info(rocsparse_csrgemm_info       dest,
 /********************************************************************************
  * \brief Destroy csrgemm info.
  *******************************************************************************/
-rocsparse_status rocsparse_destroy_csrgemm_info(rocsparse_csrgemm_info info)
+rocsparse_status rocsparse::destroy_csrgemm_info(rocsparse_csrgemm_info info)
 {
     if(info == nullptr)
     {
@@ -846,10 +846,10 @@ rocsparse_status rocsparse_destroy_csrgemm_info(rocsparse_csrgemm_info info)
 /********************************************************************************
  * \brief rocsparse_csritsv_info is a structure holding the rocsparse csritsv
  * info data gathered during csritsv_buffer_size. It must be initialized using
- * the rocsparse_create_csritsv_info() routine. It should be destroyed at the
- * end using rocsparse_destroy_csritsv_info().
+ * the create_csritsv_info() routine. It should be destroyed at the
+ * end using destroy_csritsv_info().
  *******************************************************************************/
-rocsparse_status rocsparse_create_csritsv_info(rocsparse_csritsv_info* info)
+rocsparse_status rocsparse::create_csritsv_info(rocsparse_csritsv_info* info)
 {
     if(info == nullptr)
     {
@@ -873,8 +873,8 @@ rocsparse_status rocsparse_create_csritsv_info(rocsparse_csritsv_info* info)
 /********************************************************************************
  * \brief Copy csritsv info.
  *******************************************************************************/
-rocsparse_status rocsparse_copy_csritsv_info(rocsparse_csritsv_info       dest,
-                                             const rocsparse_csritsv_info src)
+rocsparse_status rocsparse::copy_csritsv_info(rocsparse_csritsv_info       dest,
+                                              const rocsparse_csritsv_info src)
 {
     if(dest == nullptr || src == nullptr || dest == src)
     {
@@ -890,7 +890,7 @@ rocsparse_status rocsparse_copy_csritsv_info(rocsparse_csritsv_info       dest,
 /********************************************************************************
  * \brief Destroy csritsv info.
  *******************************************************************************/
-rocsparse_status rocsparse_destroy_csritsv_info(rocsparse_csritsv_info info)
+rocsparse_status rocsparse::destroy_csritsv_info(rocsparse_csritsv_info info)
 {
     if(info == nullptr)
     {
@@ -970,12 +970,51 @@ struct XnackMode<PROP, void_t<decltype(PROP::gcnArchName)>>
     }
 };
 
-std::string rocsparse_handle_get_arch_name(rocsparse_handle handle)
+std::string rocsparse::handle_get_arch_name(rocsparse_handle handle)
 {
     return ArchName<hipDeviceProp_t>{}(handle->properties);
 }
 
-std::string rocsparse_handle_get_xnack_mode(rocsparse_handle handle)
+std::string rocsparse::handle_get_xnack_mode(rocsparse_handle handle)
 {
     return XnackMode<hipDeviceProp_t>{}(handle->properties);
 }
+
+/*******************************************************************************
+ * \brief convert hipError_t to rocsparse_status
+ * TODO - enumerate library calls to hip runtime, enumerate possible errors from
+ * those calls
+ ******************************************************************************/
+rocsparse_status rocsparse::get_rocsparse_status_for_hip_status(hipError_t status)
+{
+    switch(status)
+    {
+    // success
+    case hipSuccess:
+        return rocsparse_status_success;
+
+    // internal hip memory allocation
+    case hipErrorMemoryAllocation:
+    case hipErrorLaunchOutOfResources:
+        return rocsparse_status_memory_error;
+
+    // user-allocated hip memory
+    case hipErrorInvalidDevicePointer: // hip memory
+        return rocsparse_status_invalid_pointer;
+
+    // user-allocated device, stream, event
+    case hipErrorInvalidDevice:
+    case hipErrorInvalidResourceHandle:
+        return rocsparse_status_invalid_handle;
+
+    // library using hip incorrectly
+    case hipErrorInvalidValue:
+        return rocsparse_status_internal_error;
+
+    // hip runtime failing
+    case hipErrorNoDevice: // no hip devices
+    case hipErrorUnknown:
+    default:
+        return rocsparse_status_internal_error;
+    }
+}
