@@ -1,6 +1,6 @@
 /*! \file */
 /* ************************************************************************
- * Copyright (C) 2018-2023 Advanced Micro Devices, Inc. All rights Reserved.
+ * Copyright (C) 2018-2024 Advanced Micro Devices, Inc. All rights Reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -30,8 +30,6 @@
 #include "rocsparse_blas.h"
 #include <fstream>
 #include <hip/hip_runtime_api.h>
-#include <iostream>
-#include <vector>
 
 /*! \brief typedefs to opaque info structs */
 typedef struct _rocsparse_trm_info*     rocsparse_trm_info;
@@ -86,7 +84,7 @@ struct _rocsparse_handle
     rocsparse_float_complex*  cone{};
     rocsparse_double_complex* zone{};
     // blas handle
-    rocsparse_blas_handle blas_handle;
+    rocsparse::blas_handle blas_handle;
 
     // logging streams
     std::ofstream log_trace_ofs;
@@ -216,10 +214,10 @@ struct _rocsparse_color_info
 
 struct rocsparse_adaptive_info
 {
-    size_t        size{}; // num row blocks
-    void*         row_blocks{};
-    unsigned int* wg_flags{};
-    void*         wg_ids{};
+    size_t    size{}; // num row blocks
+    void*     row_blocks{};
+    uint32_t* wg_flags{};
+    void*     wg_ids{};
 };
 
 struct rocsparse_lrb_info
@@ -228,8 +226,8 @@ struct rocsparse_lrb_info
     void* rows_bins{}; // size of m
     void* n_rows_bins{}; // size of 32
 
-    size_t        size{};
-    unsigned int* wg_flags{};
+    size_t    size{};
+    uint32_t* wg_flags{};
 
     int64_t nRowsBins[32]{}; // host array
 };
@@ -237,8 +235,8 @@ struct rocsparse_lrb_info
 /********************************************************************************
  * \brief rocsparse_csrmv_info is a structure holding the rocsparse csrmv info
  * data gathered during csrmv_analysis. It must be initialized using the
- * rocsparse_create_csrmv_info() routine. It should be destroyed at the end
- * rocsparse_destroy_csrmv_info().
+ * create_csrmv_info() routine. It should be destroyed at the end
+ * destroy_csrmv_info().
  *******************************************************************************/
 struct _rocsparse_csrmv_info
 {
@@ -259,24 +257,26 @@ struct _rocsparse_csrmv_info
     rocsparse_indextype index_type_J = rocsparse_indextype_u16;
 };
 
-/********************************************************************************
+namespace rocsparse
+{
+    /********************************************************************************
  * \brief rocsparse_csrmv_info is a structure holding the rocsparse csrmv info
  * data gathered during csrmv_analysis. It must be initialized using the
- * rocsparse_create_csrmv_info() routine. It should be destroyed at the end
- * using rocsparse_destroy_csrmv_info().
+ * create_csrmv_info() routine. It should be destroyed at the end
+ * using destroy_csrmv_info().
  *******************************************************************************/
-rocsparse_status rocsparse_create_csrmv_info(rocsparse_csrmv_info* info);
+    rocsparse_status create_csrmv_info(rocsparse_csrmv_info* info);
 
-/********************************************************************************
+    /********************************************************************************
  * \brief Copy csrmv info.
  *******************************************************************************/
-rocsparse_status rocsparse_copy_csrmv_info(rocsparse_csrmv_info       dest,
-                                           const rocsparse_csrmv_info src);
+    rocsparse_status copy_csrmv_info(rocsparse_csrmv_info dest, const rocsparse_csrmv_info src);
 
-/********************************************************************************
+    /********************************************************************************
  * \brief Destroy csrmv info.
  *******************************************************************************/
-rocsparse_status rocsparse_destroy_csrmv_info(rocsparse_csrmv_info info);
+    rocsparse_status destroy_csrmv_info(rocsparse_csrmv_info info);
+}
 
 struct _rocsparse_trm_info
 {
@@ -303,36 +303,39 @@ struct _rocsparse_trm_info
     rocsparse_indextype index_type_J = rocsparse_indextype_u16;
 };
 
-/********************************************************************************
+namespace rocsparse
+{
+    /********************************************************************************
  * \brief rocsparse_trm_info is a structure holding the rocsparse bsrsv, csrsv,
  * csrsm, csrilu0 and csric0 data gathered during csrsv_analysis,
  * csrilu0_analysis and csric0_analysis. It must be initialized using the
- * rocsparse_create_trm_info() routine. It should be destroyed at the end
- * using rocsparse_destroy_trm_info().
+ * create_trm_info() routine. It should be destroyed at the end
+ * using destroy_trm_info().
  *******************************************************************************/
-rocsparse_status rocsparse_create_trm_info(rocsparse_trm_info* info);
+    rocsparse_status create_trm_info(rocsparse_trm_info* info);
 
-/********************************************************************************
+    /********************************************************************************
  * \brief Copy trm info.
  *******************************************************************************/
-rocsparse_status rocsparse_copy_trm_info(rocsparse_trm_info dest, const rocsparse_trm_info src);
+    rocsparse_status copy_trm_info(rocsparse_trm_info dest, const rocsparse_trm_info src);
 
-/********************************************************************************
+    /********************************************************************************
  * \brief Destroy trm info.
  *******************************************************************************/
-rocsparse_status rocsparse_destroy_trm_info(rocsparse_trm_info info);
+    rocsparse_status destroy_trm_info(rocsparse_trm_info info);
 
-/********************************************************************************
- * \brief rocsparse_check_trm_shared checks if the given trm info structure
+    /********************************************************************************
+ * \brief check_trm_shared checks if the given trm info structure
  * shares its meta data with another trm info structure.
  *******************************************************************************/
-bool rocsparse_check_trm_shared(const rocsparse_mat_info info, rocsparse_trm_info trm);
+    bool check_trm_shared(const rocsparse_mat_info info, rocsparse_trm_info trm);
+}
 
 /********************************************************************************
  * \brief rocsparse_csritsv_info is a structure holding the rocsparse csritsv
  * info data gathered during csritsv_buffer_size. It must be initialized using
- * the rocsparse_create_csritsv_info() routine. It should be destroyed at the
- * end using rocsparse_destroy_csritsv_info().
+ * the create_csritsv_info() routine. It should be destroyed at the
+ * end using destroy_csritsv_info().
  *******************************************************************************/
 struct _rocsparse_csritsv_info
 {
@@ -342,30 +345,33 @@ struct _rocsparse_csritsv_info
     void*               ptr_end{};
 };
 
-/********************************************************************************
+namespace rocsparse
+{
+    /********************************************************************************
  * \brief rocsparse_csritsv_info is a structure holding the rocsparse csritsv
  * info data gathered during csritsv_buffer_size. It must be initialized using
- * the rocsparse_create_csritsv_info() routine. It should be destroyed at the
- * end using rocsparse_destroy_csritsv_info().
+ * the create_csritsv_info() routine. It should be destroyed at the
+ * end using destroy_csritsv_info().
  *******************************************************************************/
-rocsparse_status rocsparse_create_csritsv_info(rocsparse_csritsv_info* info);
+    rocsparse_status create_csritsv_info(rocsparse_csritsv_info* info);
 
-/********************************************************************************
+    /********************************************************************************
  * \brief Copy csritsv info.
  *******************************************************************************/
-rocsparse_status rocsparse_copy_csritsv_info(rocsparse_csritsv_info       dest,
-                                             const rocsparse_csritsv_info src);
+    rocsparse_status copy_csritsv_info(rocsparse_csritsv_info       dest,
+                                       const rocsparse_csritsv_info src);
 
-/********************************************************************************
+    /********************************************************************************
  * \brief Destroy csritsv info.
  *******************************************************************************/
-rocsparse_status rocsparse_destroy_csritsv_info(rocsparse_csritsv_info info);
+    rocsparse_status destroy_csritsv_info(rocsparse_csritsv_info info);
+}
 
 /********************************************************************************
  * \brief rocsparse_csrgemm_info is a structure holding the rocsparse csrgemm
  * info data gathered during csrgemm_buffer_size. It must be initialized using
- * the rocsparse_create_csrgemm_info() routine. It should be destroyed at the
- * end using rocsparse_destroy_csrgemm_info().
+ * the create_csrgemm_info() routine. It should be destroyed at the
+ * end using destroy_csrgemm_info().
  *******************************************************************************/
 struct _rocsparse_csrgemm_info
 {
@@ -377,24 +383,27 @@ struct _rocsparse_csrgemm_info
     bool add{true};
 };
 
-/********************************************************************************
+namespace rocsparse
+{
+    /********************************************************************************
  * \brief rocsparse_csrgemm_info is a structure holding the rocsparse csrgemm
  * info data gathered during csrgemm_buffer_size. It must be initialized using
- * the rocsparse_create_csrgemm_info() routine. It should be destroyed at the
- * end using rocsparse_destroy_csrgemm_info().
+ * the create_csrgemm_info() routine. It should be destroyed at the
+ * end using destroy_csrgemm_info().
  *******************************************************************************/
-rocsparse_status rocsparse_create_csrgemm_info(rocsparse_csrgemm_info* info);
+    rocsparse_status create_csrgemm_info(rocsparse_csrgemm_info* info);
 
-/********************************************************************************
+    /********************************************************************************
  * \brief Copy csrgemm info.
  *******************************************************************************/
-rocsparse_status rocsparse_copy_csrgemm_info(rocsparse_csrgemm_info       dest,
-                                             const rocsparse_csrgemm_info src);
+    rocsparse_status copy_csrgemm_info(rocsparse_csrgemm_info       dest,
+                                       const rocsparse_csrgemm_info src);
 
-/********************************************************************************
+    /********************************************************************************
  * \brief Destroy csrgemm info.
  *******************************************************************************/
-rocsparse_status rocsparse_destroy_csrgemm_info(rocsparse_csrgemm_info info);
+    rocsparse_status destroy_csrgemm_info(rocsparse_csrgemm_info info);
+}
 
 /********************************************************************************
  * \brief ELL format indexing
@@ -492,17 +501,20 @@ struct _rocsparse_dnmat_descr
     int64_t batch_stride{};
 };
 
-//
-// Get architecture name.
-//
-std::string rocsparse_handle_get_arch_name(rocsparse_handle handle);
-
-struct rocpsarse_arch_names
+namespace rocsparse
 {
-    static constexpr const char* gfx908 = "gfx908";
-};
+    //
+    // Get architecture name.
+    //
+    std::string handle_get_arch_name(rocsparse_handle handle);
 
-//
-// Get xnack mode.
-//
-std::string rocsparse_handle_get_xnack_mode(rocsparse_handle handle);
+    struct rocpsarse_arch_names
+    {
+        static constexpr const char* gfx908 = "gfx908";
+    };
+
+    //
+    // Get xnack mode.
+    //
+    std::string handle_get_xnack_mode(rocsparse_handle handle);
+}
