@@ -1,6 +1,6 @@
 /*! \file */
 /* ************************************************************************
- * Copyright (C) 2018-2023 Advanced Micro Devices, Inc. All rights Reserved.
+ * Copyright (C) 2018-2024 Advanced Micro Devices, Inc. All rights Reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -28,23 +28,23 @@
 #include "../conversion/rocsparse_csr2coo.hpp"
 #include "../conversion/rocsparse_identity.hpp"
 #include "../level1/rocsparse_gthr.hpp"
+#include "control.h"
 #include "csrsv_device.h"
-#include "definitions.h"
 #include "utility.h"
 #include <rocprim/rocprim.hpp>
 
 template <typename I, typename J, typename T>
-rocsparse_status rocsparse_trm_analysis(rocsparse_handle          handle,
-                                        rocsparse_operation       trans,
-                                        J                         m,
-                                        I                         nnz,
-                                        const rocsparse_mat_descr descr,
-                                        const T*                  csr_val,
-                                        const I*                  csr_row_ptr,
-                                        const J*                  csr_col_ind,
-                                        rocsparse_trm_info        info,
-                                        J**                       zero_pivot,
-                                        void*                     temp_buffer)
+rocsparse_status rocsparse::trm_analysis(rocsparse_handle          handle,
+                                         rocsparse_operation       trans,
+                                         J                         m,
+                                         I                         nnz,
+                                         const rocsparse_mat_descr descr,
+                                         const T*                  csr_val,
+                                         const I*                  csr_row_ptr,
+                                         const J*                  csr_col_ind,
+                                         rocsparse_trm_info        info,
+                                         J**                       zero_pivot,
+                                         void*                     temp_buffer)
 {
     // Stream
     hipStream_t stream = handle->stream;
@@ -91,14 +91,14 @@ rocsparse_status rocsparse_trm_analysis(rocsparse_handle          handle,
 
             // Create identity permutation
             RETURN_IF_ROCSPARSE_ERROR(
-                rocsparse_create_identity_permutation_template(handle, nnz, (I*)info->trmt_perm));
+                rocsparse::create_identity_permutation_template(handle, nnz, (I*)info->trmt_perm));
 
             // Stable sort COO by columns
             rocprim::double_buffer<J> keys(tmp_work1, (J*)info->trmt_col_ind);
             rocprim::double_buffer<I> vals((I*)info->trmt_perm, tmp_work2);
 
-            unsigned int startbit = 0;
-            unsigned int endbit   = rocsparse_clz(m);
+            uint32_t startbit = 0;
+            uint32_t endbit   = rocsparse::clz(m);
 
             size_t rocprim_size;
 
@@ -118,24 +118,24 @@ rocsparse_status rocsparse_trm_analysis(rocsparse_handle          handle,
             }
 
             // Create column pointers
-            RETURN_IF_ROCSPARSE_ERROR(rocsparse_coo2csr_template(
+            RETURN_IF_ROCSPARSE_ERROR(rocsparse::coo2csr_template(
                 handle, keys.current(), nnz, m, (I*)info->trmt_row_ptr, descr->base));
 
             // Create row indices
             RETURN_IF_ROCSPARSE_ERROR(
-                rocsparse_csr2coo_template(handle, csr_row_ptr, nnz, m, tmp_work1, descr->base));
+                rocsparse::csr2coo_template(handle, csr_row_ptr, nnz, m, tmp_work1, descr->base));
 
             // Permute column indices
-            RETURN_IF_ROCSPARSE_ERROR(rocsparse_gthr_template(handle,
-                                                              nnz,
-                                                              tmp_work1,
-                                                              (J*)info->trmt_col_ind,
-                                                              (const I*)info->trmt_perm,
-                                                              rocsparse_index_base_zero));
+            RETURN_IF_ROCSPARSE_ERROR(rocsparse::gthr_template(handle,
+                                                               nnz,
+                                                               tmp_work1,
+                                                               (J*)info->trmt_col_ind,
+                                                               (const I*)info->trmt_perm,
+                                                               rocsparse_index_base_zero));
         }
         else
         {
-            RETURN_IF_HIPLAUNCHKERNELGGL_ERROR((set_array_to_value<256, J, I>),
+            RETURN_IF_HIPLAUNCHKERNELGGL_ERROR((rocsparse::set_array_to_value<256, J, I>),
                                                dim3(m / 256 + 1),
                                                dim3(256),
                                                0,
@@ -186,10 +186,11 @@ rocsparse_status rocsparse_trm_analysis(rocsparse_handle          handle,
     RETURN_IF_HIP_ERROR(rocsparse_hipMallocAsync((void**)&info->row_map, sizeof(J) * m, stream));
 
     // Initialize zero pivot
-    RETURN_IF_HIP_ERROR(rocsparse_assign_async(*zero_pivot, std::numeric_limits<J>::max(), stream));
+    RETURN_IF_HIP_ERROR(
+        rocsparse::assign_async(*zero_pivot, std::numeric_limits<J>::max(), stream));
 
     // Determine archid and ASIC revision
-    const std::string gcn_arch_name = rocsparse_handle_get_arch_name(handle);
+    const std::string gcn_arch_name = rocsparse::handle_get_arch_name(handle);
     const int         asicRev       = handle->asic_rev;
 
     // Run analysis
@@ -205,7 +206,7 @@ rocsparse_status rocsparse_trm_analysis(rocsparse_handle          handle,
             if(descr->fill_mode == rocsparse_fill_mode_upper)
             {
                 RETURN_IF_HIPLAUNCHKERNELGGL_ERROR(
-                    (csrsv_analysis_upper_kernel<CSRSV_DIM, 64, true>),
+                    (rocsparse::csrsv_analysis_upper_kernel<CSRSV_DIM, 64, true>),
                     csrsv_blocks,
                     csrsv_threads,
                     0,
@@ -223,7 +224,7 @@ rocsparse_status rocsparse_trm_analysis(rocsparse_handle          handle,
             else if(descr->fill_mode == rocsparse_fill_mode_lower)
             {
                 RETURN_IF_HIPLAUNCHKERNELGGL_ERROR(
-                    (csrsv_analysis_lower_kernel<CSRSV_DIM, 64, true>),
+                    (rocsparse::csrsv_analysis_lower_kernel<CSRSV_DIM, 64, true>),
                     csrsv_blocks,
                     csrsv_threads,
                     0,
@@ -248,7 +249,7 @@ rocsparse_status rocsparse_trm_analysis(rocsparse_handle          handle,
                 if(descr->fill_mode == rocsparse_fill_mode_upper)
                 {
                     RETURN_IF_HIPLAUNCHKERNELGGL_ERROR(
-                        (csrsv_analysis_upper_kernel<CSRSV_DIM, 32, false>),
+                        (rocsparse::csrsv_analysis_upper_kernel<CSRSV_DIM, 32, false>),
                         csrsv_blocks,
                         csrsv_threads,
                         0,
@@ -266,7 +267,7 @@ rocsparse_status rocsparse_trm_analysis(rocsparse_handle          handle,
                 else if(descr->fill_mode == rocsparse_fill_mode_lower)
                 {
                     RETURN_IF_HIPLAUNCHKERNELGGL_ERROR(
-                        (csrsv_analysis_lower_kernel<CSRSV_DIM, 32, false>),
+                        (rocsparse::csrsv_analysis_lower_kernel<CSRSV_DIM, 32, false>),
                         csrsv_blocks,
                         csrsv_threads,
                         0,
@@ -285,11 +286,12 @@ rocsparse_status rocsparse_trm_analysis(rocsparse_handle          handle,
             }
             else
             {
-                assert(handle->wavefront_size == 64);
+                rocsparse_host_assert(handle->wavefront_size == 64,
+                                      "Wrong wavefront size dispatch.");
                 if(descr->fill_mode == rocsparse_fill_mode_upper)
                 {
                     RETURN_IF_HIPLAUNCHKERNELGGL_ERROR(
-                        (csrsv_analysis_upper_kernel<CSRSV_DIM, 64, false>),
+                        (rocsparse::csrsv_analysis_upper_kernel<CSRSV_DIM, 64, false>),
                         csrsv_blocks,
                         csrsv_threads,
                         0,
@@ -307,7 +309,7 @@ rocsparse_status rocsparse_trm_analysis(rocsparse_handle          handle,
                 else if(descr->fill_mode == rocsparse_fill_mode_lower)
                 {
                     RETURN_IF_HIPLAUNCHKERNELGGL_ERROR(
-                        (csrsv_analysis_lower_kernel<CSRSV_DIM, 64, false>),
+                        (rocsparse::csrsv_analysis_lower_kernel<CSRSV_DIM, 64, false>),
                         csrsv_blocks,
                         csrsv_threads,
                         0,
@@ -334,7 +336,7 @@ rocsparse_status rocsparse_trm_analysis(rocsparse_handle          handle,
             if(descr->fill_mode == rocsparse_fill_mode_upper)
             {
                 RETURN_IF_HIPLAUNCHKERNELGGL_ERROR(
-                    (csrsv_analysis_lower_kernel<CSRSV_DIM, 64, true>),
+                    (rocsparse::csrsv_analysis_lower_kernel<CSRSV_DIM, 64, true>),
                     csrsv_blocks,
                     csrsv_threads,
                     0,
@@ -352,7 +354,7 @@ rocsparse_status rocsparse_trm_analysis(rocsparse_handle          handle,
             else if(descr->fill_mode == rocsparse_fill_mode_lower)
             {
                 RETURN_IF_HIPLAUNCHKERNELGGL_ERROR(
-                    (csrsv_analysis_upper_kernel<CSRSV_DIM, 64, true>),
+                    (rocsparse::csrsv_analysis_upper_kernel<CSRSV_DIM, 64, true>),
                     csrsv_blocks,
                     csrsv_threads,
                     0,
@@ -377,7 +379,7 @@ rocsparse_status rocsparse_trm_analysis(rocsparse_handle          handle,
                 if(descr->fill_mode == rocsparse_fill_mode_upper)
                 {
                     RETURN_IF_HIPLAUNCHKERNELGGL_ERROR(
-                        (csrsv_analysis_lower_kernel<CSRSV_DIM, 32, false>),
+                        (rocsparse::csrsv_analysis_lower_kernel<CSRSV_DIM, 32, false>),
                         csrsv_blocks,
                         csrsv_threads,
                         0,
@@ -395,7 +397,7 @@ rocsparse_status rocsparse_trm_analysis(rocsparse_handle          handle,
                 else if(descr->fill_mode == rocsparse_fill_mode_lower)
                 {
                     RETURN_IF_HIPLAUNCHKERNELGGL_ERROR(
-                        (csrsv_analysis_upper_kernel<CSRSV_DIM, 32, false>),
+                        (rocsparse::csrsv_analysis_upper_kernel<CSRSV_DIM, 32, false>),
                         csrsv_blocks,
                         csrsv_threads,
                         0,
@@ -414,11 +416,12 @@ rocsparse_status rocsparse_trm_analysis(rocsparse_handle          handle,
             }
             else
             {
-                assert(handle->wavefront_size == 64);
+                rocsparse_host_assert(handle->wavefront_size == 64,
+                                      "Wrong wavefront size dispatch.");
                 if(descr->fill_mode == rocsparse_fill_mode_upper)
                 {
                     RETURN_IF_HIPLAUNCHKERNELGGL_ERROR(
-                        (csrsv_analysis_lower_kernel<CSRSV_DIM, 64, false>),
+                        (rocsparse::csrsv_analysis_lower_kernel<CSRSV_DIM, 64, false>),
                         csrsv_blocks,
                         csrsv_threads,
                         0,
@@ -436,7 +439,7 @@ rocsparse_status rocsparse_trm_analysis(rocsparse_handle          handle,
                 else if(descr->fill_mode == rocsparse_fill_mode_lower)
                 {
                     RETURN_IF_HIPLAUNCHKERNELGGL_ERROR(
-                        (csrsv_analysis_upper_kernel<CSRSV_DIM, 64, false>),
+                        (rocsparse::csrsv_analysis_upper_kernel<CSRSV_DIM, 64, false>),
                         csrsv_blocks,
                         csrsv_threads,
                         0,
@@ -469,12 +472,13 @@ rocsparse_status rocsparse_trm_analysis(rocsparse_handle          handle,
     // Wait for host transfer to finish
     RETURN_IF_HIP_ERROR(hipStreamSynchronize(stream));
 
-    RETURN_IF_ROCSPARSE_ERROR(rocsparse_create_identity_permutation_template(handle, m, workspace));
+    RETURN_IF_ROCSPARSE_ERROR(
+        rocsparse::create_identity_permutation_template(handle, m, workspace));
 
     size_t rocprim_size;
 
-    unsigned int startbit = 0;
-    unsigned int endbit   = rocsparse_clz(m);
+    uint32_t startbit = 0;
+    uint32_t endbit   = rocsparse::clz(m);
 
     rocprim::double_buffer<int> keys(done_array, workspace2);
     rocprim::double_buffer<J>   vals(workspace, (J*)info->row_map);
@@ -511,18 +515,18 @@ rocsparse_status rocsparse_trm_analysis(rocsparse_handle          handle,
 }
 
 template <typename I, typename J, typename T>
-rocsparse_status rocsparse_csrsv_analysis_template(rocsparse_handle          handle,
-                                                   rocsparse_operation       trans,
-                                                   J                         m,
-                                                   I                         nnz,
-                                                   const rocsparse_mat_descr descr,
-                                                   const T*                  csr_val,
-                                                   const I*                  csr_row_ptr,
-                                                   const J*                  csr_col_ind,
-                                                   rocsparse_mat_info        info,
-                                                   rocsparse_analysis_policy analysis,
-                                                   rocsparse_solve_policy    solve,
-                                                   void*                     temp_buffer)
+rocsparse_status rocsparse::csrsv_analysis_template(rocsparse_handle          handle,
+                                                    rocsparse_operation       trans,
+                                                    J                         m,
+                                                    I                         nnz,
+                                                    const rocsparse_mat_descr descr,
+                                                    const T*                  csr_val,
+                                                    const I*                  csr_row_ptr,
+                                                    const J*                  csr_col_ind,
+                                                    rocsparse_mat_info        info,
+                                                    rocsparse_analysis_policy analysis,
+                                                    rocsparse_solve_policy    solve,
+                                                    void*                     temp_buffer)
 {
     // Check for valid handle and matrix descriptor
     ROCSPARSE_CHECKARG_HANDLE(0, handle);
@@ -530,19 +534,19 @@ rocsparse_status rocsparse_csrsv_analysis_template(rocsparse_handle          han
     ROCSPARSE_CHECKARG_POINTER(8, info);
 
     // Logging
-    log_trace(handle,
-              replaceX<T>("rocsparse_Xcsrsv_analysis"),
-              trans,
-              m,
-              nnz,
-              (const void*&)descr,
-              (const void*&)csr_val,
-              (const void*&)csr_row_ptr,
-              (const void*&)csr_col_ind,
-              (const void*&)info,
-              solve,
-              analysis,
-              (const void*&)temp_buffer);
+    rocsparse::log_trace(handle,
+                         rocsparse::replaceX<T>("rocsparse_Xcsrsv_analysis"),
+                         trans,
+                         m,
+                         nnz,
+                         (const void*&)descr,
+                         (const void*&)csr_val,
+                         (const void*&)csr_row_ptr,
+                         (const void*&)csr_col_ind,
+                         (const void*&)info,
+                         solve,
+                         analysis,
+                         (const void*&)temp_buffer);
 
     ROCSPARSE_CHECKARG_ENUM(1, trans);
     ROCSPARSE_CHECKARG_ENUM(9, analysis);
@@ -629,17 +633,17 @@ rocsparse_status rocsparse_csrsv_analysis_template(rocsparse_handle          han
         // found to be re-used.
 
         // Clear csrsv info
-        RETURN_IF_ROCSPARSE_ERROR(rocsparse_destroy_trm_info((trans == rocsparse_operation_none)
-                                                                 ? info->csrsv_upper_info
-                                                                 : info->csrsvt_upper_info));
+        RETURN_IF_ROCSPARSE_ERROR(rocsparse::destroy_trm_info((trans == rocsparse_operation_none)
+                                                                  ? info->csrsv_upper_info
+                                                                  : info->csrsvt_upper_info));
 
         // Create csrsv info
-        RETURN_IF_ROCSPARSE_ERROR(rocsparse_create_trm_info((trans == rocsparse_operation_none)
-                                                                ? &info->csrsv_upper_info
-                                                                : &info->csrsvt_upper_info));
+        RETURN_IF_ROCSPARSE_ERROR(rocsparse::create_trm_info((trans == rocsparse_operation_none)
+                                                                 ? &info->csrsv_upper_info
+                                                                 : &info->csrsvt_upper_info));
 
         // Perform analysis
-        RETURN_IF_ROCSPARSE_ERROR(rocsparse_trm_analysis(
+        RETURN_IF_ROCSPARSE_ERROR(rocsparse::trm_analysis(
             handle,
             trans,
             m,
@@ -715,17 +719,17 @@ rocsparse_status rocsparse_csrsv_analysis_template(rocsparse_handle          han
         // found to be re-used.
 
         // Clear csrsv info
-        RETURN_IF_ROCSPARSE_ERROR(rocsparse_destroy_trm_info((trans == rocsparse_operation_none)
-                                                                 ? info->csrsv_lower_info
-                                                                 : info->csrsvt_lower_info));
+        RETURN_IF_ROCSPARSE_ERROR(rocsparse::destroy_trm_info((trans == rocsparse_operation_none)
+                                                                  ? info->csrsv_lower_info
+                                                                  : info->csrsvt_lower_info));
 
         // Create csrsv info
-        RETURN_IF_ROCSPARSE_ERROR(rocsparse_create_trm_info((trans == rocsparse_operation_none)
-                                                                ? &info->csrsv_lower_info
-                                                                : &info->csrsvt_lower_info));
+        RETURN_IF_ROCSPARSE_ERROR(rocsparse::create_trm_info((trans == rocsparse_operation_none)
+                                                                 ? &info->csrsv_lower_info
+                                                                 : &info->csrsvt_lower_info));
 
         // Perform analysis
-        RETURN_IF_ROCSPARSE_ERROR(rocsparse_trm_analysis(
+        RETURN_IF_ROCSPARSE_ERROR(rocsparse::trm_analysis(
             handle,
             trans,
             m,
@@ -742,18 +746,18 @@ rocsparse_status rocsparse_csrsv_analysis_template(rocsparse_handle          han
     return rocsparse_status_success;
 }
 
-#define INSTANTIATE(ITYPE, JTYPE, TTYPE)                                                    \
-    template rocsparse_status rocsparse_trm_analysis(rocsparse_handle          handle,      \
-                                                     rocsparse_operation       trans,       \
-                                                     JTYPE                     m,           \
-                                                     ITYPE                     nnz,         \
-                                                     const rocsparse_mat_descr descr,       \
-                                                     const TTYPE*              csr_val,     \
-                                                     const ITYPE*              csr_row_ptr, \
-                                                     const JTYPE*              csr_col_ind, \
-                                                     rocsparse_trm_info        info,        \
-                                                     JTYPE**                   zero_pivot,  \
-                                                     void*                     temp_buffer);
+#define INSTANTIATE(ITYPE, JTYPE, TTYPE)                                                     \
+    template rocsparse_status rocsparse::trm_analysis(rocsparse_handle          handle,      \
+                                                      rocsparse_operation       trans,       \
+                                                      JTYPE                     m,           \
+                                                      ITYPE                     nnz,         \
+                                                      const rocsparse_mat_descr descr,       \
+                                                      const TTYPE*              csr_val,     \
+                                                      const ITYPE*              csr_row_ptr, \
+                                                      const JTYPE*              csr_col_ind, \
+                                                      rocsparse_trm_info        info,        \
+                                                      JTYPE**                   zero_pivot,  \
+                                                      void*                     temp_buffer);
 
 INSTANTIATE(int32_t, int32_t, float);
 INSTANTIATE(int32_t, int32_t, double);
@@ -769,19 +773,19 @@ INSTANTIATE(int64_t, int64_t, rocsparse_float_complex);
 INSTANTIATE(int64_t, int64_t, rocsparse_double_complex);
 #undef INSTANTIATE
 
-#define INSTANTIATE(ITYPE, JTYPE, TTYPE)                         \
-    template rocsparse_status rocsparse_csrsv_analysis_template( \
-        rocsparse_handle          handle,                        \
-        rocsparse_operation       trans,                         \
-        JTYPE                     m,                             \
-        ITYPE                     nnz,                           \
-        const rocsparse_mat_descr descr,                         \
-        const TTYPE*              csr_val,                       \
-        const ITYPE*              csr_row_ptr,                   \
-        const JTYPE*              csr_col_ind,                   \
-        rocsparse_mat_info        info,                          \
-        rocsparse_analysis_policy analysis,                      \
-        rocsparse_solve_policy    solve,                         \
+#define INSTANTIATE(ITYPE, JTYPE, TTYPE)                          \
+    template rocsparse_status rocsparse::csrsv_analysis_template( \
+        rocsparse_handle          handle,                         \
+        rocsparse_operation       trans,                          \
+        JTYPE                     m,                              \
+        ITYPE                     nnz,                            \
+        const rocsparse_mat_descr descr,                          \
+        const TTYPE*              csr_val,                        \
+        const ITYPE*              csr_row_ptr,                    \
+        const JTYPE*              csr_col_ind,                    \
+        rocsparse_mat_info        info,                           \
+        rocsparse_analysis_policy analysis,                       \
+        rocsparse_solve_policy    solve,                          \
         void*                     temp_buffer);
 
 INSTANTIATE(int32_t, int32_t, float);
@@ -804,38 +808,38 @@ INSTANTIATE(int64_t, int64_t, rocsparse_double_complex);
  * ===========================================================================
  */
 
-#define C_IMPL(NAME, TYPE)                                                         \
-    extern "C" rocsparse_status NAME(rocsparse_handle          handle,             \
-                                     rocsparse_operation       trans,              \
-                                     rocsparse_int             m,                  \
-                                     rocsparse_int             nnz,                \
-                                     const rocsparse_mat_descr descr,              \
-                                     const TYPE*               csr_val,            \
-                                     const rocsparse_int*      csr_row_ptr,        \
-                                     const rocsparse_int*      csr_col_ind,        \
-                                     rocsparse_mat_info        info,               \
-                                     rocsparse_analysis_policy analysis,           \
-                                     rocsparse_solve_policy    solve,              \
-                                     void*                     temp_buffer)        \
-    try                                                                            \
-    {                                                                              \
-        RETURN_IF_ROCSPARSE_ERROR(rocsparse_csrsv_analysis_template(handle,        \
-                                                                    trans,         \
-                                                                    m,             \
-                                                                    nnz,           \
-                                                                    descr,         \
-                                                                    csr_val,       \
-                                                                    csr_row_ptr,   \
-                                                                    csr_col_ind,   \
-                                                                    info,          \
-                                                                    analysis,      \
-                                                                    solve,         \
-                                                                    temp_buffer)); \
-        return rocsparse_status_success;                                           \
-    }                                                                              \
-    catch(...)                                                                     \
-    {                                                                              \
-        RETURN_ROCSPARSE_EXCEPTION();                                              \
+#define C_IMPL(NAME, TYPE)                                                          \
+    extern "C" rocsparse_status NAME(rocsparse_handle          handle,              \
+                                     rocsparse_operation       trans,               \
+                                     rocsparse_int             m,                   \
+                                     rocsparse_int             nnz,                 \
+                                     const rocsparse_mat_descr descr,               \
+                                     const TYPE*               csr_val,             \
+                                     const rocsparse_int*      csr_row_ptr,         \
+                                     const rocsparse_int*      csr_col_ind,         \
+                                     rocsparse_mat_info        info,                \
+                                     rocsparse_analysis_policy analysis,            \
+                                     rocsparse_solve_policy    solve,               \
+                                     void*                     temp_buffer)         \
+    try                                                                             \
+    {                                                                               \
+        RETURN_IF_ROCSPARSE_ERROR(rocsparse::csrsv_analysis_template(handle,        \
+                                                                     trans,         \
+                                                                     m,             \
+                                                                     nnz,           \
+                                                                     descr,         \
+                                                                     csr_val,       \
+                                                                     csr_row_ptr,   \
+                                                                     csr_col_ind,   \
+                                                                     info,          \
+                                                                     analysis,      \
+                                                                     solve,         \
+                                                                     temp_buffer)); \
+        return rocsparse_status_success;                                            \
+    }                                                                               \
+    catch(...)                                                                      \
+    {                                                                               \
+        RETURN_ROCSPARSE_EXCEPTION();                                               \
     }
 
 C_IMPL(rocsparse_scsrsv_analysis, float);
