@@ -1,6 +1,6 @@
 /*! \file */
 /* ************************************************************************
- * Copyright (C) 2022-2023 Advanced Micro Devices, Inc.
+ * Copyright (C) 2022-2024 Advanced Micro Devices, Inc.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -33,7 +33,7 @@
 #include "rocsparse_csritilu0x_preprocess.hpp"
 
 template <>
-struct rocsparse_csritilu0_driver_t<rocsparse_itilu0_alg_sync_split_fusion>
+struct rocsparse::csritilu0_driver_t<rocsparse_itilu0_alg_sync_split_fusion>
 {
 
     //
@@ -57,7 +57,7 @@ struct rocsparse_csritilu0_driver_t<rocsparse_itilu0_alg_sync_split_fusion>
             RETURN_IF_HIP_ERROR(hipStreamSynchronize(handle_->stream));
             void*  p_buffer      = layout_.get_pointer(layout_t::buffer);
             size_t p_buffer_size = layout_.get_size(layout_t::buffer);
-            RETURN_IF_ROCSPARSE_ERROR((rocsparse_csritilu0x_history_template<T, J>(
+            RETURN_IF_ROCSPARSE_ERROR((rocsparse::csritilu0x_history_template<T, J>(
                 handle_, alg_, niter_, data_, p_buffer_size, p_buffer)));
             return rocsparse_status_success;
         }
@@ -127,22 +127,22 @@ struct rocsparse_csritilu0_driver_t<rocsparse_itilu0_alg_sync_split_fusion>
 
             size_t buffer_size_csritilu0x = 0;
             RETURN_IF_ROCSPARSE_ERROR(
-                rocsparse_csritilu0x_buffer_size_template(handle_,
-                                                          alg_,
-                                                          options_,
-                                                          nsweeps_,
-                                                          m_,
-                                                          nnz_,
-                                                          ptr_,
-                                                          ptr_ + 1,
-                                                          ind_,
-                                                          base_,
-                                                          rocsparse_diag_type_unit,
-                                                          rocsparse_direction_row,
-                                                          rocsparse_diag_type_unit,
-                                                          rocsparse_direction_column,
-                                                          datatype_,
-                                                          &buffer_size_csritilu0x));
+                rocsparse::csritilu0x_buffer_size_template(handle_,
+                                                           alg_,
+                                                           options_,
+                                                           nsweeps_,
+                                                           m_,
+                                                           nnz_,
+                                                           ptr_,
+                                                           ptr_ + 1,
+                                                           ind_,
+                                                           base_,
+                                                           rocsparse_diag_type_unit,
+                                                           rocsparse_direction_row,
+                                                           rocsparse_diag_type_unit,
+                                                           rocsparse_direction_column,
+                                                           datatype_,
+                                                           &buffer_size_csritilu0x));
 
             //
             // buffer csxsldu
@@ -150,26 +150,26 @@ struct rocsparse_csritilu0_driver_t<rocsparse_itilu0_alg_sync_split_fusion>
             const size_t buffer_size_identity = sizeof(I) * nnz_;
             size_t       buffer_size_csxsldu  = 0;
             RETURN_IF_ROCSPARSE_ERROR(
-                (rocsparse_csxsldu_buffer_size_template<I, I, J>(handle_,
-                                                                 rocsparse_direction_row,
-                                                                 m_,
-                                                                 m_,
-                                                                 nnz_,
-                                                                 ptr_,
-                                                                 ind_,
-                                                                 nullptr,
-                                                                 base_,
-                                                                 rocsparse_diag_type_unit,
-                                                                 rocsparse_direction_row,
-                                                                 rocsparse_diag_type_unit,
-                                                                 rocsparse_direction_column,
-                                                                 &buffer_size_csxsldu)));
+                (rocsparse::csxsldu_buffer_size_template<I, I, J>(handle_,
+                                                                  rocsparse_direction_row,
+                                                                  m_,
+                                                                  m_,
+                                                                  nnz_,
+                                                                  ptr_,
+                                                                  ind_,
+                                                                  nullptr,
+                                                                  base_,
+                                                                  rocsparse_diag_type_unit,
+                                                                  rocsparse_direction_row,
+                                                                  rocsparse_diag_type_unit,
+                                                                  rocsparse_direction_column,
+                                                                  &buffer_size_csxsldu)));
 
             buffer_size_csxsldu += buffer_size_identity;
             //
             // buffer csritilu0x
             //
-            buffer_size += std::max(buffer_size_csxsldu, buffer_size_csritilu0x);
+            buffer_size += rocsparse::max(buffer_size_csxsldu, buffer_size_csritilu0x);
             *buffer_size_ = buffer_size;
             return rocsparse_status_success;
         }
@@ -221,31 +221,31 @@ struct rocsparse_csritilu0_driver_t<rocsparse_itilu0_alg_sync_split_fusion>
             //
             // Set perm to identity.
             //
-            I* identity = assign_b<I>(p_buffer_size, p_buffer, nnz_);
+            I* identity = rocsparse::assign_b<I>(p_buffer_size, p_buffer, nnz_);
             RETURN_IF_ROCSPARSE_ERROR(
-                rocsparse_create_identity_permutation_core(handle_, nnz_, identity));
+                rocsparse::create_identity_permutation_core(handle_, nnz_, identity));
 
             RETURN_IF_ROCSPARSE_ERROR(
-                (rocsparse_csxsldu_preprocess_template<I, I, J>(handle_,
-                                                                rocsparse_direction_row,
-                                                                m_,
-                                                                m_,
-                                                                nnz_,
-                                                                ptr_,
-                                                                ind_,
-                                                                identity,
-                                                                base_,
-                                                                rocsparse_diag_type_unit,
-                                                                rocsparse_direction_row,
-                                                                &host_lnnz,
-                                                                p_lptr,
-                                                                base_,
-                                                                rocsparse_diag_type_unit,
-                                                                rocsparse_direction_column,
-                                                                &host_unnz,
-                                                                p_uptr,
-                                                                base_,
-                                                                p_buffer)));
+                (rocsparse::csxsldu_preprocess_template<I, I, J>(handle_,
+                                                                 rocsparse_direction_row,
+                                                                 m_,
+                                                                 m_,
+                                                                 nnz_,
+                                                                 ptr_,
+                                                                 ind_,
+                                                                 identity,
+                                                                 base_,
+                                                                 rocsparse_diag_type_unit,
+                                                                 rocsparse_direction_row,
+                                                                 &host_lnnz,
+                                                                 p_lptr,
+                                                                 base_,
+                                                                 rocsparse_diag_type_unit,
+                                                                 rocsparse_direction_column,
+                                                                 &host_unnz,
+                                                                 p_uptr,
+                                                                 base_,
+                                                                 p_buffer)));
             RETURN_IF_HIP_ERROR(hipMemcpyAsync(
                 p_lnnz, &host_lnnz, sizeof(I), hipMemcpyHostToDevice, handle_->stream));
             RETURN_IF_HIP_ERROR(hipMemcpyAsync(
@@ -270,40 +270,40 @@ struct rocsparse_csritilu0_driver_t<rocsparse_itilu0_alg_sync_split_fusion>
             I* p_uval = p_perm + host_lnnz;
             I* p_diag = p_perm + host_lnnz + host_unnz;
             RETURN_IF_ROCSPARSE_ERROR(
-                (rocsparse_csxsldu_compute_template<I, I, J>(handle_,
-                                                             rocsparse_direction_row,
-                                                             m_,
-                                                             m_,
-                                                             nnz_,
+                (rocsparse::csxsldu_compute_template<I, I, J>(handle_,
+                                                              rocsparse_direction_row,
+                                                              m_,
+                                                              m_,
+                                                              nnz_,
 
-                                                             ptr_,
-                                                             ind_,
-                                                             identity,
-                                                             base_,
-                                                             rocsparse_diag_type_unit,
+                                                              ptr_,
+                                                              ind_,
+                                                              identity,
+                                                              base_,
+                                                              rocsparse_diag_type_unit,
 
-                                                             rocsparse_direction_row,
-                                                             host_lnnz,
-                                                             p_lptr,
-                                                             p_lind,
-                                                             p_lval,
+                                                              rocsparse_direction_row,
+                                                              host_lnnz,
+                                                              p_lptr,
+                                                              p_lind,
+                                                              p_lval,
 
-                                                             base_,
-                                                             rocsparse_diag_type_unit,
-                                                             rocsparse_direction_column,
-                                                             host_unnz,
-                                                             p_uptr,
+                                                              base_,
+                                                              rocsparse_diag_type_unit,
+                                                              rocsparse_direction_column,
+                                                              host_unnz,
+                                                              p_uptr,
 
-                                                             p_uind,
-                                                             p_uval,
-                                                             base_,
-                                                             p_diag,
-                                                             p_buffer)));
+                                                              p_uind,
+                                                              p_uval,
+                                                              base_,
+                                                              p_diag,
+                                                              p_buffer)));
 
             //
             // Free identity from the buffer.
             //
-            identity = unassign_b<I>(p_buffer_size, p_buffer, nnz_);
+            identity = rocsparse::unassign_b<I>(p_buffer_size, p_buffer, nnz_);
 
             //
             // The buffer need to be kept. Get the buffer from layout since we need to preserve x.
@@ -311,33 +311,33 @@ struct rocsparse_csritilu0_driver_t<rocsparse_itilu0_alg_sync_split_fusion>
             p_buffer      = layout.get_pointer(layout_t::buffer);
             p_buffer_size = layout.get_size(layout_t::buffer);
             RETURN_IF_ROCSPARSE_ERROR(
-                (rocsparse_csritilu0x_preprocess_template(handle_,
-                                                          alg_,
-                                                          options_,
-                                                          nsweeps_,
-                                                          m_,
-                                                          nnz_,
-                                                          ptr_,
-                                                          ptr_ + 1,
-                                                          ind_,
-                                                          base_,
-                                                          rocsparse_diag_type_unit,
-                                                          rocsparse_direction_row,
-                                                          host_lnnz,
-                                                          p_lptr,
-                                                          p_lptr + 1,
-                                                          p_lind,
-                                                          base_,
-                                                          rocsparse_diag_type_unit,
-                                                          rocsparse_direction_column,
-                                                          host_unnz,
-                                                          p_uptr,
-                                                          p_uptr + 1,
-                                                          p_uind,
-                                                          base_,
-                                                          datatype_,
-                                                          p_buffer_size,
-                                                          p_buffer)));
+                (rocsparse::csritilu0x_preprocess_template(handle_,
+                                                           alg_,
+                                                           options_,
+                                                           nsweeps_,
+                                                           m_,
+                                                           nnz_,
+                                                           ptr_,
+                                                           ptr_ + 1,
+                                                           ind_,
+                                                           base_,
+                                                           rocsparse_diag_type_unit,
+                                                           rocsparse_direction_row,
+                                                           host_lnnz,
+                                                           p_lptr,
+                                                           p_lptr + 1,
+                                                           p_lind,
+                                                           base_,
+                                                           rocsparse_diag_type_unit,
+                                                           rocsparse_direction_column,
+                                                           host_unnz,
+                                                           p_uptr,
+                                                           p_uptr + 1,
+                                                           p_uind,
+                                                           base_,
+                                                           datatype_,
+                                                           p_buffer_size,
+                                                           p_buffer)));
 
             //
             // Copy the struct to device.
@@ -385,7 +385,7 @@ struct rocsparse_csritilu0_driver_t<rocsparse_itilu0_alg_sync_split_fusion>
     {
         static rocsparse_status run(rocsparse_handle     handle_,
                                     rocsparse_itilu0_alg alg_,
-                                    J                    options_,
+                                    rocsparse_int        options_,
                                     J*                   nsweeps_,
                                     floating_data_t<T>   tol_,
                                     J                    m_,
@@ -436,77 +436,77 @@ struct rocsparse_csritilu0_driver_t<rocsparse_itilu0_alg_sync_split_fusion>
             //
             // Copy solution_ to X, solution and X are of the same size.
             //
-            rocsparse_get_permuted_array<BLOCKSIZE_PERM>(handle_, nnz_, sol_, p_x, p_perm);
+            rocsparse::get_permuted_array<BLOCKSIZE_PERM>(handle_, nnz_, sol_, p_x, p_perm);
 
             //
             // Compute expert routine.
             //
             RETURN_IF_ROCSPARSE_ERROR(
-                rocsparse_csritilu0x_compute_template(handle_,
-                                                      alg_,
-                                                      options_,
-                                                      nsweeps_,
-                                                      tol_,
-                                                      m_,
-                                                      nnz_,
-                                                      ptr_,
-                                                      ptr_ + 1,
-                                                      ind_,
-                                                      val_,
-                                                      base_,
-                                                      rocsparse_diag_type_unit,
-                                                      rocsparse_direction_row,
-                                                      host_lnnz,
-                                                      p_lptr,
-                                                      p_lptr + 1,
-                                                      p_lind,
-                                                      p_lval,
-                                                      base_,
-                                                      rocsparse_diag_type_unit,
-                                                      rocsparse_direction_column,
-                                                      host_unnz,
-                                                      p_uptr,
-                                                      p_uptr + 1,
-                                                      p_uind,
-                                                      p_uval,
-                                                      base_,
-                                                      p_dval,
-                                                      p_buffer_size,
-                                                      p_buffer));
+                rocsparse::csritilu0x_compute_template(handle_,
+                                                       alg_,
+                                                       options_,
+                                                       nsweeps_,
+                                                       tol_,
+                                                       m_,
+                                                       nnz_,
+                                                       ptr_,
+                                                       ptr_ + 1,
+                                                       ind_,
+                                                       val_,
+                                                       base_,
+                                                       rocsparse_diag_type_unit,
+                                                       rocsparse_direction_row,
+                                                       host_lnnz,
+                                                       p_lptr,
+                                                       p_lptr + 1,
+                                                       p_lind,
+                                                       p_lval,
+                                                       base_,
+                                                       rocsparse_diag_type_unit,
+                                                       rocsparse_direction_column,
+                                                       host_unnz,
+                                                       p_uptr,
+                                                       p_uptr + 1,
+                                                       p_uind,
+                                                       p_uval,
+                                                       base_,
+                                                       p_dval,
+                                                       p_buffer_size,
+                                                       p_buffer));
 
             //
             // Move factorization to matrix.
             //
-            rocsparse_set_permuted_array<BLOCKSIZE_PERM>(handle_, nnz_, sol_, p_x, p_perm);
+            rocsparse::set_permuted_array<BLOCKSIZE_PERM>(handle_, nnz_, sol_, p_x, p_perm);
             return rocsparse_status_success;
         }
     };
 };
 
-#define INSTANTIATE(T, I, J)                      \
-    template struct rocsparse_csritilu0_driver_t< \
+#define INSTANTIATE(T, I, J)                       \
+    template struct rocsparse::csritilu0_driver_t< \
         rocsparse_itilu0_alg_sync_split_fusion>::compute<T, I, J>
 
-INSTANTIATE(float, int32_t, int32_t);
-INSTANTIATE(double, int32_t, int32_t);
-INSTANTIATE(rocsparse_float_complex, int32_t, int32_t);
-INSTANTIATE(rocsparse_double_complex, int32_t, int32_t);
+INSTANTIATE(float, rocsparse_int, rocsparse_int);
+INSTANTIATE(double, rocsparse_int, rocsparse_int);
+INSTANTIATE(rocsparse_float_complex, rocsparse_int, rocsparse_int);
+INSTANTIATE(rocsparse_double_complex, rocsparse_int, rocsparse_int);
 
 #undef INSTANTIATE
 
-#define INSTANTIATE(T, J)                         \
-    template struct rocsparse_csritilu0_driver_t< \
+#define INSTANTIATE(T, J)                          \
+    template struct rocsparse::csritilu0_driver_t< \
         rocsparse_itilu0_alg_sync_split_fusion>::history<T, J>
 
-INSTANTIATE(float, int32_t);
-INSTANTIATE(double, int32_t);
+INSTANTIATE(float, rocsparse_int);
+INSTANTIATE(double, rocsparse_int);
 
 #undef INSTANTIATE
 
 #define INSTANTIATE(I, J)                                           \
-    template struct rocsparse_csritilu0_driver_t<                   \
+    template struct rocsparse::csritilu0_driver_t<                  \
         rocsparse_itilu0_alg_sync_split_fusion>::buffer_size<I, J>; \
-    template struct rocsparse_csritilu0_driver_t<                   \
+    template struct rocsparse::csritilu0_driver_t<                  \
         rocsparse_itilu0_alg_sync_split_fusion>::preprocess<I, J>;
 
 INSTANTIATE(rocsparse_int, rocsparse_int);
