@@ -1,6 +1,6 @@
 /*! \file */
 /* ************************************************************************
- * Copyright (C) 2022-2023 Advanced Micro Devices, Inc. All rights Reserved.
+ * Copyright (C) 2022-2024 Advanced Micro Devices, Inc. All rights Reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -22,50 +22,47 @@
  *
  * ************************************************************************ */
 #include "internal/util/rocsparse_check_matrix_csr.h"
-#include "definitions.h"
 #include "rocsparse_check_matrix_csr.hpp"
+#include "to_string.hpp"
 #include "utility.h"
 
 #include "check_matrix_csr_device.h"
 
 #include <rocprim/rocprim.hpp>
-std::string rocsparse_matrixtype2string(rocsparse_matrix_type type);
 
-const char* rocsparse_datastatus2string(rocsparse_data_status data_status);
-
-#define LAUNCH_CHECK_MATRIX_CSR(block_size, wf_size)                                   \
-    RETURN_IF_HIPLAUNCHKERNELGGL_ERROR((check_matrix_csr_device<block_size, wf_size>), \
-                                       dim3((wf_size * m - 1) / block_size + 1),       \
-                                       dim3(block_size),                               \
-                                       0,                                              \
-                                       handle->stream,                                 \
-                                       m,                                              \
-                                       n,                                              \
-                                       nnz,                                            \
-                                       csr_val,                                        \
-                                       csr_row_ptr,                                    \
-                                       csr_col_ind,                                    \
-                                       csr_col_ind_sorted,                             \
-                                       idx_base,                                       \
-                                       matrix_type,                                    \
-                                       uplo,                                           \
-                                       storage,                                        \
+#define LAUNCH_CHECK_MATRIX_CSR(block_size, wf_size)                                              \
+    RETURN_IF_HIPLAUNCHKERNELGGL_ERROR((rocsparse::check_matrix_csr_device<block_size, wf_size>), \
+                                       dim3((wf_size * m - 1) / block_size + 1),                  \
+                                       dim3(block_size),                                          \
+                                       0,                                                         \
+                                       handle->stream,                                            \
+                                       m,                                                         \
+                                       n,                                                         \
+                                       nnz,                                                       \
+                                       csr_val,                                                   \
+                                       csr_row_ptr,                                               \
+                                       csr_col_ind,                                               \
+                                       csr_col_ind_sorted,                                        \
+                                       idx_base,                                                  \
+                                       matrix_type,                                               \
+                                       uplo,                                                      \
+                                       storage,                                                   \
                                        d_data_status);
 
 template <typename T, typename I, typename J>
-rocsparse_status rocsparse_check_matrix_csr_core(rocsparse_handle       handle,
-                                                 J                      m,
-                                                 J                      n,
-                                                 I                      nnz,
-                                                 const T*               csr_val,
-                                                 const I*               csr_row_ptr,
-                                                 const J*               csr_col_ind,
-                                                 rocsparse_index_base   idx_base,
-                                                 rocsparse_matrix_type  matrix_type,
-                                                 rocsparse_fill_mode    uplo,
-                                                 rocsparse_storage_mode storage,
-                                                 rocsparse_data_status* data_status,
-                                                 void*                  temp_buffer)
+rocsparse_status rocsparse::check_matrix_csr_core(rocsparse_handle       handle,
+                                                  J                      m,
+                                                  J                      n,
+                                                  I                      nnz,
+                                                  const T*               csr_val,
+                                                  const I*               csr_row_ptr,
+                                                  const J*               csr_col_ind,
+                                                  rocsparse_index_base   idx_base,
+                                                  rocsparse_matrix_type  matrix_type,
+                                                  rocsparse_fill_mode    uplo,
+                                                  rocsparse_storage_mode storage,
+                                                  rocsparse_data_status* data_status,
+                                                  void*                  temp_buffer)
 {
 
     // Check that nnz matches row pointer array
@@ -80,7 +77,7 @@ rocsparse_status rocsparse_check_matrix_csr_core(rocsparse_handle       handle,
 
     if(nnz != (end - start))
     {
-        log_debug(handle, "CSR row pointer array does not match nnz.");
+        rocsparse::log_debug(handle, "CSR row pointer array does not match nnz.");
         RETURN_IF_ROCSPARSE_ERROR(rocsparse_status_invalid_value);
     }
 
@@ -96,7 +93,7 @@ rocsparse_status rocsparse_check_matrix_csr_core(rocsparse_handle       handle,
     RETURN_IF_HIP_ERROR(hipMemsetAsync(d_data_status, 0, sizeof(rocsparse_data_status)));
     RETURN_IF_HIP_ERROR(hipStreamSynchronize(handle->stream));
 
-    RETURN_IF_HIPLAUNCHKERNELGGL_ERROR((check_row_ptr_array<256>),
+    RETURN_IF_HIPLAUNCHKERNELGGL_ERROR((rocsparse::check_row_ptr_array<256>),
                                        dim3((m - 1) / 256 + 1),
                                        dim3(256),
                                        0,
@@ -114,7 +111,7 @@ rocsparse_status rocsparse_check_matrix_csr_core(rocsparse_handle       handle,
 
     if(*data_status != rocsparse_data_status_success)
     {
-        log_debug(handle, rocsparse_datastatus2string(*data_status));
+        rocsparse::log_debug(handle, rocsparse::to_string(*data_status));
 
         return rocsparse_status_success;
     }
@@ -128,9 +125,9 @@ rocsparse_status rocsparse_check_matrix_csr_core(rocsparse_handle       handle,
     // If columns are unsorted, then sort them in temp buffer
     if(storage == rocsparse_storage_mode_unsorted)
     {
-        unsigned int startbit = 0;
-        unsigned int endbit   = rocsparse_clz(n);
-        size_t       size;
+        uint32_t startbit = 0;
+        uint32_t endbit   = rocsparse::clz(n);
+        size_t   size;
 
         // offsets buffer
         tmp_offsets = reinterpret_cast<I*>(ptr);
@@ -144,7 +141,7 @@ rocsparse_status rocsparse_check_matrix_csr_core(rocsparse_handle       handle,
         tmp_cols2 = reinterpret_cast<J*>(ptr);
         ptr += ((sizeof(J) * nnz - 1) / 256 + 1) * 256;
 
-        RETURN_IF_HIPLAUNCHKERNELGGL_ERROR((shift_offsets_kernel<512>),
+        RETURN_IF_HIPLAUNCHKERNELGGL_ERROR((rocsparse::shift_offsets_kernel<512>),
                                            dim3(m / 512 + 1),
                                            dim3(512),
                                            0,
@@ -286,44 +283,47 @@ rocsparse_status rocsparse_check_matrix_csr_core(rocsparse_handle       handle,
 
     if(*data_status != rocsparse_data_status_success)
     {
-        log_debug(handle, rocsparse_datastatus2string(*data_status));
+        rocsparse::log_debug(handle, rocsparse::to_string(*data_status));
     }
 
     return rocsparse_status_success;
 }
 
-template <typename T, typename I, typename J>
-rocsparse_status rocsparse_check_matrix_csr_quickreturn(rocsparse_handle       handle,
-                                                        J                      m,
-                                                        J                      n,
-                                                        I                      nnz,
-                                                        const T*               csr_val,
-                                                        const I*               csr_row_ptr,
-                                                        const J*               csr_col_ind,
-                                                        rocsparse_index_base   idx_base,
-                                                        rocsparse_matrix_type  matrix_type,
-                                                        rocsparse_fill_mode    uplo,
-                                                        rocsparse_storage_mode storage,
-                                                        rocsparse_data_status* data_status,
-                                                        void*                  temp_buffer)
+namespace rocsparse
 {
-    return rocsparse_status_continue;
+    template <typename T, typename I, typename J>
+    static rocsparse_status check_matrix_csr_quickreturn(rocsparse_handle       handle,
+                                                         J                      m,
+                                                         J                      n,
+                                                         I                      nnz,
+                                                         const T*               csr_val,
+                                                         const I*               csr_row_ptr,
+                                                         const J*               csr_col_ind,
+                                                         rocsparse_index_base   idx_base,
+                                                         rocsparse_matrix_type  matrix_type,
+                                                         rocsparse_fill_mode    uplo,
+                                                         rocsparse_storage_mode storage,
+                                                         rocsparse_data_status* data_status,
+                                                         void*                  temp_buffer)
+    {
+        return rocsparse_status_continue;
+    }
 }
 
 template <typename T, typename I, typename J>
-rocsparse_status rocsparse_check_matrix_csr_checkarg(rocsparse_handle       handle, //0
-                                                     J                      m, //1
-                                                     J                      n, //2
-                                                     I                      nnz, //3
-                                                     const T*               csr_val, //4
-                                                     const I*               csr_row_ptr, //5
-                                                     const J*               csr_col_ind, //6
-                                                     rocsparse_index_base   idx_base, //7
-                                                     rocsparse_matrix_type  matrix_type, //8
-                                                     rocsparse_fill_mode    uplo, //9
-                                                     rocsparse_storage_mode storage, //10
-                                                     rocsparse_data_status* data_status, //11
-                                                     void*                  temp_buffer) //12
+rocsparse_status rocsparse::check_matrix_csr_checkarg(rocsparse_handle       handle, //0
+                                                      J                      m, //1
+                                                      J                      n, //2
+                                                      I                      nnz, //3
+                                                      const T*               csr_val, //4
+                                                      const I*               csr_row_ptr, //5
+                                                      const J*               csr_col_ind, //6
+                                                      rocsparse_index_base   idx_base, //7
+                                                      rocsparse_matrix_type  matrix_type, //8
+                                                      rocsparse_fill_mode    uplo, //9
+                                                      rocsparse_storage_mode storage, //10
+                                                      rocsparse_data_status* data_status, //11
+                                                      void*                  temp_buffer) //12
 {
     ROCSPARSE_CHECKARG_HANDLE(0, handle);
     ROCSPARSE_CHECKARG_SIZE(1, m);
@@ -343,9 +343,10 @@ rocsparse_status rocsparse_check_matrix_csr_checkarg(rocsparse_handle       hand
     {
         if(m != n)
         {
-            log_debug(handle,
-                      ("Matrix was specified to be " + rocsparse_matrixtype2string(matrix_type)
-                       + " but m != n"));
+            rocsparse::log_debug(handle,
+                                 ("Matrix was specified to be "
+                                  + std::string(rocsparse::to_string(matrix_type))
+                                  + " but m != n"));
         }
     }
     ROCSPARSE_CHECKARG(2,
@@ -353,19 +354,19 @@ rocsparse_status rocsparse_check_matrix_csr_checkarg(rocsparse_handle       hand
                        ((matrix_type != rocsparse_matrix_type_general) && (n != m)),
                        rocsparse_status_invalid_size);
 
-    const rocsparse_status status = rocsparse_check_matrix_csr_quickreturn(handle,
-                                                                           m,
-                                                                           n,
-                                                                           nnz,
-                                                                           csr_val,
-                                                                           csr_row_ptr,
-                                                                           csr_col_ind,
-                                                                           idx_base,
-                                                                           matrix_type,
-                                                                           uplo,
-                                                                           storage,
-                                                                           data_status,
-                                                                           temp_buffer);
+    const rocsparse_status status = rocsparse::check_matrix_csr_quickreturn(handle,
+                                                                            m,
+                                                                            n,
+                                                                            nnz,
+                                                                            csr_val,
+                                                                            csr_row_ptr,
+                                                                            csr_col_ind,
+                                                                            idx_base,
+                                                                            matrix_type,
+                                                                            uplo,
+                                                                            storage,
+                                                                            data_status,
+                                                                            temp_buffer);
     if(status != rocsparse_status_continue)
     {
         RETURN_IF_ROCSPARSE_ERROR(status);
@@ -378,14 +379,14 @@ rocsparse_status rocsparse_check_matrix_csr_checkarg(rocsparse_handle       hand
 template <typename T, typename I, typename J, typename... P>
 rocsparse_status rocsparse_check_matrix_csr_template(P&&... p)
 {
-    const rocsparse_status status = rocsparse_check_matrix_csr_quickreturn<T, I, J>(p...);
+    const rocsparse_status status = rocsparse::check_matrix_csr_quickreturn<T, I, J>(p...);
     if(status != rocsparse_status_continue)
     {
         RETURN_IF_ROCSPARSE_ERROR(status);
         return rocsparse_status_success;
     }
 
-    RETURN_IF_ROCSPARSE_ERROR((rocsparse_check_matrix_csr_core<T, I, J>(p...)));
+    RETURN_IF_ROCSPARSE_ERROR((rocsparse::check_matrix_csr_core<T, I, J>(p...)));
     if(status != rocsparse_status_continue)
     {
         RETURN_IF_ROCSPARSE_ERROR(status);
@@ -395,34 +396,34 @@ rocsparse_status rocsparse_check_matrix_csr_template(P&&... p)
     return rocsparse_status_success;
 }
 
-#define INSTANTIATE(I, J, T)                                                \
-    template rocsparse_status rocsparse_check_matrix_csr_core<T, I, J>(     \
-        rocsparse_handle       handle,                                      \
-        J                      m,                                           \
-        J                      n,                                           \
-        I                      nnz,                                         \
-        const T*               csr_val,                                     \
-        const I*               csr_row_ptr,                                 \
-        const J*               csr_col_ind,                                 \
-        rocsparse_index_base   idx_base,                                    \
-        rocsparse_matrix_type  matrix_type,                                 \
-        rocsparse_fill_mode    uplo,                                        \
-        rocsparse_storage_mode storage,                                     \
-        rocsparse_data_status* data_status,                                 \
-        void*                  temp_buffer);                                                 \
-    template rocsparse_status rocsparse_check_matrix_csr_checkarg<T, I, J>( \
-        rocsparse_handle       handle,                                      \
-        J                      m,                                           \
-        J                      n,                                           \
-        I                      nnz,                                         \
-        const T*               csr_val,                                     \
-        const I*               csr_row_ptr,                                 \
-        const J*               csr_col_ind,                                 \
-        rocsparse_index_base   idx_base,                                    \
-        rocsparse_matrix_type  matrix_type,                                 \
-        rocsparse_fill_mode    uplo,                                        \
-        rocsparse_storage_mode storage,                                     \
-        rocsparse_data_status* data_status,                                 \
+#define INSTANTIATE(I, J, T)                                                 \
+    template rocsparse_status rocsparse::check_matrix_csr_core<T, I, J>(     \
+        rocsparse_handle       handle,                                       \
+        J                      m,                                            \
+        J                      n,                                            \
+        I                      nnz,                                          \
+        const T*               csr_val,                                      \
+        const I*               csr_row_ptr,                                  \
+        const J*               csr_col_ind,                                  \
+        rocsparse_index_base   idx_base,                                     \
+        rocsparse_matrix_type  matrix_type,                                  \
+        rocsparse_fill_mode    uplo,                                         \
+        rocsparse_storage_mode storage,                                      \
+        rocsparse_data_status* data_status,                                  \
+        void*                  temp_buffer);                                                  \
+    template rocsparse_status rocsparse::check_matrix_csr_checkarg<T, I, J>( \
+        rocsparse_handle       handle,                                       \
+        J                      m,                                            \
+        J                      n,                                            \
+        I                      nnz,                                          \
+        const T*               csr_val,                                      \
+        const I*               csr_row_ptr,                                  \
+        const J*               csr_col_ind,                                  \
+        rocsparse_index_base   idx_base,                                     \
+        rocsparse_matrix_type  matrix_type,                                  \
+        rocsparse_fill_mode    uplo,                                         \
+        rocsparse_storage_mode storage,                                      \
+        rocsparse_data_status* data_status,                                  \
         void*                  temp_buffer);
 
 INSTANTIATE(int32_t, int32_t, float);
@@ -439,41 +440,41 @@ INSTANTIATE(int64_t, int64_t, rocsparse_float_complex);
 INSTANTIATE(int64_t, int64_t, rocsparse_double_complex);
 #undef INSTANTIATE
 
-#define C_IMPL(NAME, T)                                                                       \
-    extern "C" rocsparse_status NAME(rocsparse_handle       handle,                           \
-                                     rocsparse_int          m,                                \
-                                     rocsparse_int          n,                                \
-                                     rocsparse_int          nnz,                              \
-                                     const T*               csr_val,                          \
-                                     const rocsparse_int*   csr_row_ptr,                      \
-                                     const rocsparse_int*   csr_col_ind,                      \
-                                     rocsparse_index_base   idx_base,                         \
-                                     rocsparse_matrix_type  matrix_type,                      \
-                                     rocsparse_fill_mode    uplo,                             \
-                                     rocsparse_storage_mode storage,                          \
-                                     rocsparse_data_status* data_status,                      \
-                                     void*                  temp_buffer)                      \
-    try                                                                                       \
-    {                                                                                         \
-        RETURN_IF_ROCSPARSE_ERROR(                                                            \
-            (rocsparse_check_matrix_csr_impl<T, rocsparse_int, rocsparse_int>(handle,         \
-                                                                              m,              \
-                                                                              n,              \
-                                                                              nnz,            \
-                                                                              csr_val,        \
-                                                                              csr_row_ptr,    \
-                                                                              csr_col_ind,    \
-                                                                              idx_base,       \
-                                                                              matrix_type,    \
-                                                                              uplo,           \
-                                                                              storage,        \
-                                                                              data_status,    \
-                                                                              temp_buffer))); \
-        return rocsparse_status_success;                                                      \
-    }                                                                                         \
-    catch(...)                                                                                \
-    {                                                                                         \
-        RETURN_ROCSPARSE_EXCEPTION();                                                         \
+#define C_IMPL(NAME, T)                                                                        \
+    extern "C" rocsparse_status NAME(rocsparse_handle       handle,                            \
+                                     rocsparse_int          m,                                 \
+                                     rocsparse_int          n,                                 \
+                                     rocsparse_int          nnz,                               \
+                                     const T*               csr_val,                           \
+                                     const rocsparse_int*   csr_row_ptr,                       \
+                                     const rocsparse_int*   csr_col_ind,                       \
+                                     rocsparse_index_base   idx_base,                          \
+                                     rocsparse_matrix_type  matrix_type,                       \
+                                     rocsparse_fill_mode    uplo,                              \
+                                     rocsparse_storage_mode storage,                           \
+                                     rocsparse_data_status* data_status,                       \
+                                     void*                  temp_buffer)                       \
+    try                                                                                        \
+    {                                                                                          \
+        RETURN_IF_ROCSPARSE_ERROR(                                                             \
+            (rocsparse::check_matrix_csr_impl<T, rocsparse_int, rocsparse_int>(handle,         \
+                                                                               m,              \
+                                                                               n,              \
+                                                                               nnz,            \
+                                                                               csr_val,        \
+                                                                               csr_row_ptr,    \
+                                                                               csr_col_ind,    \
+                                                                               idx_base,       \
+                                                                               matrix_type,    \
+                                                                               uplo,           \
+                                                                               storage,        \
+                                                                               data_status,    \
+                                                                               temp_buffer))); \
+        return rocsparse_status_success;                                                       \
+    }                                                                                          \
+    catch(...)                                                                                 \
+    {                                                                                          \
+        RETURN_ROCSPARSE_EXCEPTION();                                                          \
     }
 
 C_IMPL(rocsparse_scheck_matrix_csr, float);
